@@ -23,19 +23,25 @@
 
 static void orz_charlist_class_init (OrzCharlistClass *klass);
 static void orz_charlist_init       (OrzCharlist      *charlist);
-static void orz_charlist_close      (OrzCharlist      *charlist);
+static void orz_charlist_escape     (OrzCharlist      *charlist);
 
 
-static GtkWindowClass *parent_class = NULL;
+static GtkDialogClass *parent_class = NULL;
 
 
 enum
 {
-  CLOSE_SIGNAL,
+  ESCAPE_SIGNAL,
   LAST_SIGNAL
 };
 
 
+enum
+{
+  TARGET_GTK_TREE_MODEL_ROW
+};
+
+
 static gint orz_charlist_signals[LAST_SIGNAL] = {0};
 
 
@@ -49,7 +55,7 @@ orz_charlist_get_type (void)
 
   if (!orz_charlist_type)
     {
-      static const GTypeInfo charlist_info =
+      const static GTypeInfo charlist_info =
       {
         sizeof (OrzCharlistClass),
         NULL,               /* base_init */
@@ -62,7 +68,7 @@ orz_charlist_get_type (void)
         (GInstanceInitFunc)orz_charlist_init,
       };
 
-      orz_charlist_type = g_type_register_static (GTK_TYPE_WINDOW,
+      orz_charlist_type = g_type_register_static (GTK_TYPE_DIALOG,
                                             "OrzCharlist", &charlist_info, 0);
     }
 
@@ -84,19 +90,19 @@ orz_charlist_class_init (OrzCharlistClass *klass)
 
   parent_class = g_type_class_peek_parent (klass);
 
-  klass->close = orz_charlist_close;
+  klass->escape = orz_charlist_escape;
 
-  orz_charlist_signals[CLOSE_SIGNAL]
-                = g_signal_new ("close",
+  orz_charlist_signals[ESCAPE_SIGNAL]
+                = g_signal_new ("escape",
                                 G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-                                G_STRUCT_OFFSET (OrzCharlistClass, close),
+                                G_STRUCT_OFFSET (OrzCharlistClass, escape),
                                 NULL, NULL,
                                 g_cclosure_marshal_VOID__VOID,
                                 G_TYPE_NONE, 0);
 
   binding_set = gtk_binding_set_by_class (klass);
-  gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "close", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "escape", 0);
 }
 
 
@@ -153,7 +159,8 @@ orz_charlist_clicked_new (GtkWidget   *widget,
   g_free (charset);
   orz_charset_set_charset (ORZ_CHARSET (charlist->charset), NULL);
   /* ja:OKボタン */
-  gtk_widget_set_sensitive (charlist->ok_button, TRUE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                        GTK_RESPONSE_OK, TRUE);
 }
 
 
@@ -181,7 +188,8 @@ orz_charlist_clicked_remove (GtkWidget   *widget,
         g_free (charset);
       }
   /* ja:OKボタン */
-  gtk_widget_set_sensitive (charlist->ok_button, TRUE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                        GTK_RESPONSE_OK, TRUE);
 }
 
 
@@ -214,7 +222,8 @@ orz_charlist_clicked_up (GtkWidget   *widget,
         break;
       }
   /* ja:OKボタン */
-  gtk_widget_set_sensitive (charlist->ok_button, TRUE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                        GTK_RESPONSE_OK, TRUE);
 }
 
 
@@ -247,7 +256,8 @@ orz_charlist_clicked_down (GtkWidget   *widget,
         break;
       }
   /* ja:OKボタン */
-  gtk_widget_set_sensitive (charlist->ok_button, TRUE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                        GTK_RESPONSE_OK, TRUE);
 }
 
 
@@ -290,12 +300,24 @@ orz_charlist_edited (GtkWidget   *widget,
 }
 
 
+/* ja:ドロップされたとき */
 static void
-orz_charlist_close (OrzCharlist *charset)
+orz_charlist_dialog_drag_end (GtkWidget      *widget,
+                              GdkDragContext *drag_context,
+                              OrzCharlist    *charlist)
 {
-  if (GTK_WIDGET_VISIBLE (charset->cancel_button)
-                            && GTK_WIDGET_SENSITIVE (charset->cancel_button))
-    g_signal_emit_by_name (G_OBJECT (charset->cancel_button), "clicked");
+  /* ja:OKボタン */
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                        GTK_RESPONSE_OK, TRUE);
+}
+
+
+static void
+orz_charlist_escape (OrzCharlist *charlist)
+{
+  if (GTK_WIDGET_VISIBLE (charlist->cancel_button)
+                            && GTK_WIDGET_SENSITIVE (charlist->cancel_button))
+    g_signal_emit_by_name (G_OBJECT (charlist->cancel_button), "clicked");
 }
 
 
@@ -319,12 +341,19 @@ orz_charlist_init (OrzCharlist *charlist)
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
   GtkWidget *scroll, *hbox, *vbox;
+  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW",
+    GTK_TARGET_SAME_APP | GTK_TARGET_SAME_WIDGET, TARGET_GTK_TREE_MODEL_ROW}};
 
   /* ja:メインウインドウ */
   gtk_window_set_title (GTK_WINDOW (charlist), _("Character Encoding"));
   gtk_window_set_default_size (GTK_WINDOW (charlist), 320, 240);
   g_signal_connect (G_OBJECT (charlist), "delete-event",
                                     G_CALLBACK (orz_charlist_delete), NULL);
+  /* ja:ボタン */
+  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
+  charlist->cancel_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   /* ja:リストボックス */
   charlist->store = gtk_list_store_new (1, G_TYPE_STRING);
   charlist->tview = gtk_tree_view_new_with_model
@@ -338,6 +367,13 @@ orz_charlist_init (OrzCharlist *charlist)
                                             (GTK_TREE_VIEW (charlist->tview));
   g_signal_connect (G_OBJECT (charlist->select),
                     "changed", G_CALLBACK (orz_charlist_changed), charlist);
+  /* en:Drag & Drop */
+  gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (charlist->tview),
+                                            dnd_entries, 1, GDK_ACTION_MOVE);
+  gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (charlist->tview),
+                            GDK_BUTTON1_MASK, dnd_entries, 1, GDK_ACTION_MOVE);
+  g_signal_connect (G_OBJECT (charlist->tview), "drag-end",
+                        G_CALLBACK (orz_charlist_dialog_drag_end), charlist);
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_container_add (GTK_CONTAINER (scroll), charlist->tview);
@@ -350,12 +386,10 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist->charset), "edited",
                                 G_CALLBACK (orz_charlist_edited), charlist);
   /* ja:ボタン */
-  charlist->new_button = gtk_button_new_with_mnemonic (_("_New"));
-  charlist->remove_button = gtk_button_new_with_mnemonic (_("De_lete"));
-  charlist->up_button = gtk_button_new_with_mnemonic (_("_Up"));
-  charlist->down_button = gtk_button_new_with_mnemonic (_("_Down"));
-  charlist->ok_button = gtk_button_new_with_label (_("OK"));
-  charlist->cancel_button = gtk_button_new_with_label (_("Cancel"));
+  charlist->new_button = gtk_button_new_from_stock (GTK_STOCK_NEW);
+  charlist->remove_button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  charlist->up_button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
+  charlist->down_button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
   g_signal_connect (G_OBJECT (charlist->new_button), "clicked",
                         G_CALLBACK (orz_charlist_clicked_new), charlist);
   g_signal_connect (G_OBJECT (charlist->remove_button), "clicked",
@@ -375,20 +409,17 @@ orz_charlist_init (OrzCharlist *charlist)
                                     charlist->remove_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), charlist->up_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), charlist->down_button, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), charlist->cancel_button, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), charlist->ok_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (charlist), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (charlist)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_window_set_policy (GTK_WINDOW (charlist), FALSE, TRUE, FALSE);
-  gtk_widget_show_all (vbox);
   gtk_widget_set_sensitive (charlist->new_button, FALSE);
   gtk_widget_set_sensitive (charlist->remove_button, FALSE);
   gtk_widget_set_sensitive (charlist->up_button, FALSE);
   gtk_widget_set_sensitive (charlist->down_button, FALSE);
-  gtk_widget_set_sensitive (charlist->ok_button, FALSE);
-  gtk_widget_grab_focus (charlist->cancel_button);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (charlist),
+                                                    GTK_RESPONSE_OK, FALSE);
+  gtk_widget_show_all (vbox);
 }
 
 
@@ -448,7 +479,7 @@ orz_charlist_set_charlist (OrzCharlist *charlist,
   if (!charlist || !list)
     return FALSE;
   gtk_list_store_clear (charlist->store);
-  charset = g_strsplit (list, ",", G_MAXINT);
+  charset = g_strsplit (list, ",", 0);
   for (i = 0; charset[i]; i++)
     if (charuty_is_valid (charset[i]))
       {
@@ -516,7 +547,7 @@ orz_charlist_add_candidate (OrzCharlist *charlist,
 
   if (!charlist || !candidate)
     return FALSE;
-  charset = g_strsplit (candidate, ",", G_MAXINT);
+  charset = g_strsplit (candidate, ",", 0);
   for (i = 0; charset[i]; i++)
     {
       gboolean exist = FALSE;
