@@ -55,7 +55,7 @@ orz_history_get_type (void)
 
   if (!type)
     {
-      static const GTypeInfo info =
+      const static GTypeInfo info =
       {
         sizeof (OrzHistoryClass),
         NULL,               /* base_init */
@@ -150,11 +150,7 @@ orz_history_remove (OrzHistory *history)
 
               glist = gtk_container_get_children
                                         (GTK_CONTAINER (history->menu_shell));
-              if (glist)
-                {
-                  g_free (glist);
-                }
-              else
+              if (g_list_length (glist) <= 0)
                 {
                   GtkWidget *menu_item;
 
@@ -163,6 +159,7 @@ orz_history_remove (OrzHistory *history)
                   if (menu_item)
                     gtk_widget_set_sensitive (menu_item, FALSE);
                 }
+              g_list_free (glist);
             }
         }
     }
@@ -300,6 +297,7 @@ orz_history_add_file (OrzHistory  *history,
                       gtk_menu_shell_insert
                                         (GTK_MENU_SHELL (history->menu_shell),
                                             history->menu_item_foot, position);
+                      gtk_widget_show (history->menu_item_foot);
                     }
                   menu_item = g_list_nth_data (glist,
                                     (position < 0 ? length : position) - 1);
@@ -310,18 +308,12 @@ orz_history_add_file (OrzHistory  *history,
                       gtk_menu_shell_insert
                                         (GTK_MENU_SHELL (history->menu_shell),
                                             history->menu_item_head, position);
+                      gtk_widget_show (history->menu_item_head);
                       if (position > 0)
                         position++;
                     }
                 }
-              if (position < 0)
-                gtk_menu_shell_append (GTK_MENU_SHELL (history->menu_shell),
-                                                    history_item->menu_item);
-              else if (position == 0)
-                gtk_menu_shell_prepend (GTK_MENU_SHELL (history->menu_shell),
-                                                    history_item->menu_item);
-              else
-                gtk_menu_shell_insert (GTK_MENU_SHELL (history->menu_shell),
+              gtk_menu_shell_insert (GTK_MENU_SHELL (history->menu_shell),
                                             history_item->menu_item, position);
               if (GTK_IS_MENU (history->menu_shell))
                 {
