@@ -37,9 +37,9 @@ extern gboolean userbreak;
 *                                                                             *
 ******************************************************************************/
 /*  ja:中断ダイアログ表示
-    label,説明文                                                            */
+    text,説明文                                                             */
 GtkWidget *
-abort_dialog (const gchar *label);
+abort_dialog (const gchar *text);
 
 
 #ifdef __cplusplus
