@@ -57,29 +57,14 @@ command_new (GtkWidget *widget,
 }
 
 
-#if ! defined G_OS_WIN32 && ! GTK_CHECK_VERSION(2,4,0)
-static void
-command_open_ok (GtkWidget *widget,
-                 GtkWidget *dialog)
-{
-  gchar **file;
-
-  file = g_object_get_data (G_OBJECT (dialog), "user_data");
-  *file = g_strdup (gtk_file_selection_get_filename
-                                                (GTK_FILE_SELECTION (dialog)));
-  gtk_widget_destroy (dialog);
-}
-#endif /* not defined G_OS_WIN32 and not GTK_CHECK_VERSION(2,4,0) */
-
-
 void
 command_open (GtkWidget *widget,
               gpointer   user_data)
 {
   gchar *file = NULL, *path;
-#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
   gint i;
-#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
+#endif /* GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32) */
 #ifdef G_OS_WIN32
   gchar *filter = NULL;
   gint length, pos = 0;
@@ -181,32 +166,24 @@ command_open (GtkWidget *widget,
 
       filter = gtk_file_filter_new ();
       gtk_file_filter_set_name (filter, ftype[i].text);
-      ext = g_strsplit (ftype[i].ext, G_SEARCHPATH_SEPARATOR_S, G_MAXINT);
+      ext = g_strsplit (ftype[i].ext, G_SEARCHPATH_SEPARATOR_S, 0);
       for (j = 0; ext[j]; j++)
         gtk_file_filter_add_pattern (filter, ext[j]);
       g_strfreev (ext);
       gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
       if (i == findex)
         gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
-      g_object_set_data (G_OBJECT (filter), "user_data", (gpointer)i);
+      g_object_set_data (G_OBJECT (filter), "user_data", GINT_TO_POINTER (i));
     }
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
       file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
-      findex = (gint)g_object_get_data (G_OBJECT (filter), "user_data");
+      findex = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (filter),
+                                                                "user_data"));
     }
-  gtk_widget_destroy (dialog);
 # else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog = gtk_file_selection_new (_("Open"));
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog)->ok_button),
-                            "clicked", G_CALLBACK (command_open_ok), dialog);
-  g_signal_connect_swapped
-                        (G_OBJECT (GTK_FILE_SELECTION (dialog)->cancel_button),
-            "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  g_object_set_data (G_OBJECT (dialog), "user_data", &file);
   if (open_path)
     {
       path = g_strconcat (open_path, G_SEARCHPATH_SEPARATOR_S, NULL);
@@ -214,10 +191,11 @@ command_open (GtkWidget *widget,
       g_free (path);
     }
   gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (dialog));
-  gtk_widget_show (dialog);
-  gtk_grab_add (dialog);
-  gtk_main ();
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    file = g_strdup (gtk_file_selection_get_filename
+                                                (GTK_FILE_SELECTION (dialog)));
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
+  gtk_widget_destroy (dialog);
 #endif /* not G_OS_WIN32 */
   if (file)
     {
@@ -246,18 +224,25 @@ command_save (GtkWidget *widget,
     }
   else
     {
-      gchar *text, *utf8str;
+      gboolean result = TRUE;
       const gchar *file;
 
       file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
-      utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
-      text = g_strdup_printf (_("%s\nThis file is existed.\n\nOver write?"),
-                                                                    utf8str);
-      g_free (utf8str);
-      if ((!tmaid->ft.overwrite || !fileio_isfile (file)
-                                    || misc_message_box ("Text maid",text, 1,
-                                            _("_Yes"), _("_No"), NULL) == 0)
-                                            && file_save_text (file, tmaid))
+      if (tmaid->ft.overwrite && fileio_isfile (file))
+        {
+          gchar *utf8str;
+          GtkWidget *dialog;
+
+          utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                    GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
+                    _("%s\nThis file is existed.\n\nOver write?"), utf8str);
+          g_free (utf8str);
+          result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
+          gtk_widget_destroy (dialog);
+        }
+      if (result && file_save_text (file, tmaid))
         {
           orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
           if (delete_list (&tmaid->undo) + delete_list (&tmaid->redo) > 0)
@@ -272,9 +257,9 @@ command_saveas (GtkWidget *widget,
                 gpointer   user_data)
 {
   gchar *file = NULL, *path;
-#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
   gint i;
-#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
+#endif /* GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32) */
 #ifdef G_OS_WIN32
   gchar *filter = NULL;
   gint length, pos = 0;
@@ -377,32 +362,24 @@ command_saveas (GtkWidget *widget,
 
       filter = gtk_file_filter_new ();
       gtk_file_filter_set_name (filter, ftype[i].text);
-      ext = g_strsplit (ftype[i].ext, G_SEARCHPATH_SEPARATOR_S, G_MAXINT);
+      ext = g_strsplit (ftype[i].ext, G_SEARCHPATH_SEPARATOR_S, 0);
       for (j = 0; ext[j]; j++)
         gtk_file_filter_add_pattern (filter, ext[j]);
       g_strfreev (ext);
       gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
       if (i == findex)
         gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
-      g_object_set_data (G_OBJECT (filter), "user_data", (gpointer)i);
+      g_object_set_data (G_OBJECT (filter), "user_data", GINT_TO_POINTER (i));
     }
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
       file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
-      findex = (gint)g_object_get_data (G_OBJECT (filter), "user_data");
+      findex = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (filter),
+                                                                "user_data"));
     }
-  gtk_widget_destroy (dialog);
 # else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog = gtk_file_selection_new (_("Save As"));
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog)->ok_button),
-                            "clicked", G_CALLBACK (command_open_ok), dialog);
-  g_signal_connect_swapped
-                        (G_OBJECT (GTK_FILE_SELECTION (dialog)->cancel_button),
-            "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  g_object_set_data (G_OBJECT (dialog), "user_data", &file);
   if (save_path)
     {
       path = g_strconcat (save_path, G_SEARCHPATH_SEPARATOR_S, NULL);
@@ -410,27 +387,37 @@ command_saveas (GtkWidget *widget,
       g_free (path);
     }
   gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (dialog));
-  gtk_widget_show (dialog);
-  gtk_grab_add (dialog);
-  gtk_main ();
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    file = g_strdup (gtk_file_selection_get_filename
+                                                (GTK_FILE_SELECTION (dialog)));
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
+  gtk_widget_destroy (dialog);
 #endif /* not G_OS_WIN32 */
   if (file)
     {
-      gchar *text, *utf8str;
+      gboolean result = TRUE;
       gint page_num;
       TmaidWindow *tmaid;
 
       page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
       tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-      utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
-      text = g_strdup_printf (_("%s\nThis file is existed.\n\nOver write?"),
-                                                                    utf8str);
-      g_free (utf8str);
-      if ((!tmaid->ft.overwrite || !fileio_isfile (file)
-                                    || misc_message_box ("Text maid", text, 1,
-                                            _("_Yes"), _("_No"), NULL) == 0)
-                                            && file_save_text (file, tmaid))
+      if (tmaid->ft.overwrite && fileio_isfile (file))
+        {
+          gchar *utf8str;
+#ifdef G_OS_WIN32
+          GtkWidget *dialog;
+#endif /* G_OS_WIN32 */
+
+          utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                    GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
+                    _("%s\nThis file is existed.\n\nOver write?"), utf8str);
+          g_free (utf8str);
+          result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
+          gtk_widget_destroy (dialog);
+        }
+      if (result && file_save_text (file, tmaid))
         {
           g_free (save_path);
           path = fileio_get_full_path (file);
@@ -445,7 +432,6 @@ command_saveas (GtkWidget *widget,
           set_menu_bar (tmaid);
           orz_history_add_file (ORZ_HISTORY (history), file);
         }
-      g_free (text);
       g_free (file);
   }
 }
@@ -535,7 +521,7 @@ command_property (GtkWidget *widget,
   g_memset (&ft, 0, sizeof (FileType));
   property_copy (&ft, &tmaid->ft);
   ft.charset = g_strdup (tmaid->ft.charset);
-  if (property_dialog(&ft))
+  if (property_dialog (GTK_WINDOW (window), &ft))
     {
       if (ft.ft_id < 0)
         {
@@ -723,8 +709,16 @@ void
 command_margin (GtkWidget *widget,
                 gpointer   user_data)
 {
-  if (misc_message_box ("Text maid", _("Return at Right Margin?"), 1,
-                                            _("_Yes"), _("_No"), NULL) == 0)
+  gint result;
+  GtkWidget *dialog;
+
+  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
+                            _("Return at Right Margin?"));
+  result = gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
+  if (result == GTK_RESPONSE_YES)
     margin_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
@@ -733,8 +727,16 @@ void
 command_tab (GtkWidget *widget,
              gpointer   user_data)
 {
-  if (misc_message_box ("Text maid", _("Convert Tab to Space?"), 1,
-                                            _("_Yes"), _("_No"), NULL) == 0)
+  gint result;
+  GtkWidget *dialog;
+
+  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
+                            _("Convert Tab to Space?"));
+  result = gtk_dialog_run (GTK_DIALOG (dialog));
+  gtk_widget_destroy (dialog);
+  if (result == GTK_RESPONSE_YES)
     tab_operation ((TmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
@@ -743,24 +745,31 @@ void
 command_valchr (GtkWidget *widget,
                 gpointer   user_data)
 {
-  gchar valchr;
+  gunichar valchr;
 
   if (valchr_dialog (&valchr))
     {
-      gint page_num;
-      GdkPoint select;
-      TmaidHistory *d;
-      TmaidWindow *tmaid;
+      gchar buf[6];
+      gint leng;
 
-      page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-      tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-      select = tmaid->select;
-      d = edit_operation (tmaid, &valchr, 1, TRUE, FALSE);
-      d->next = tmaid->undo;
-      tmaid->undo = d;
-      if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
-        set_menu_bar (tmaid);
-      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
+      leng = g_unichar_to_utf8 (valchr, buf);
+      if (leng > 0)
+        {
+          gint page_num;
+          GdkPoint select;
+          TmaidHistory *d;
+          TmaidWindow *tmaid;
+
+          page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
+          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+          select = tmaid->select;
+          d = edit_operation (tmaid, buf, leng, TRUE, FALSE);
+          d->next = tmaid->undo;
+          tmaid->undo = d;
+          if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
+            set_menu_bar (tmaid);
+          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
+        }
     }
 }
 
@@ -769,14 +778,14 @@ void
 command_jump (GtkWidget *widget,
               gpointer   user_data)
 {
-  JumpDialog jmp;
+  JumpConfig jmpcfg;
   TmaidWindow *tmaid;
 
   tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
-  jmp.max = tmaid->max;
-  jmp.cursor = tmaid->cursor.y + 1;
-  if (jump_dialog (&jmp) && tmaid->cursor.y != jmp.cursor - 1)
-    jump_operation (tmaid, jmp.cursor);
+  jmpcfg.max = tmaid->max;
+  jmpcfg.cursor = tmaid->cursor.y + 1;
+  if (jump_dialog (&jmpcfg) && tmaid->cursor.y != jmpcfg.cursor - 1)
+    jump_operation (tmaid, jmpcfg.cursor);
 }
 
 
@@ -866,7 +875,7 @@ command_find (GtkWidget *widget,
               find_text[0] = text;
             }
         }
-      command_next (widget, (gpointer)TRUE);
+      command_next (widget, GINT_TO_POINTER (TRUE));
     }
 }
 
@@ -885,16 +894,18 @@ command_next (GtkWidget *widget,
   dialog = abort_dialog (_("Finding"));
   gtk_grab_add (dialog);
   find_operation (tmaid, &tmaid->cursor, &tmaid->select, find_text[0],
-            (gboolean)user_data ? find_arrow : !find_arrow, find_ignorecase);
+                        GPOINTER_TO_INT (user_data) ? find_arrow : !find_arrow,
+                                                            find_ignorecase);
   gtk_grab_remove (dialog);
   gtk_widget_destroy (dialog);
   if (userbreak && tmaid->select.x < 0)
     {
-      gchar *text;
-
-      text = g_strdup_printf (_("'%s' was not fount."), find_text[0]);
-      misc_message_box ("Text maid", text, 0, _("OK"), NULL);
-      g_free (text);
+      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+                            _("'%s' was not fount."), find_text[0]);
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
       set_menu_bar (tmaid);
     }
 }
@@ -941,7 +952,7 @@ command_replace (GtkWidget *widget,
             find_num++;
           g_memmove (find_text + 1, find_text,
                                             (find_num - 1) * sizeof (gchar *));
-          find_text[0]=rp.src;
+          find_text[0] = rp.src;
         }
       else
         {
@@ -1048,37 +1059,27 @@ command_replace (GtkWidget *widget,
         }
       if (!replace)
         {
-          text = g_strdup_printf (_("'%s' was not fount."), find_text[0]);
-          misc_message_box ("Text maid", text, 0, _("OK"), NULL);
-          g_free (text);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+                            _("'%s' was not fount."), find_text[0]);
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
         }
       else if (result == REPLACE_ALL)
         {
-          text = g_strdup_printf (_("%d strings were replaced"), count);
-          misc_message_box ("Text maid", text, 0, _("OK"), NULL);
-          g_free (text);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+                            _("%d strings were replaced"), count);
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
         }
       set_menu_bar (tmaid);
     }
 }
 
 
-static void
-command_conf_ok (GtkWidget *widget,
-                 GtkWidget *dialog)
-{
-  orz_history_set_num (ORZ_HISTORY (history),
-                                    orz_conf_get_history (ORZ_CONF (dialog)));
-  newfile = orz_conf_get_newfile (ORZ_CONF (dialog));
-  second = orz_conf_get_second (ORZ_CONF (dialog));
-  orz_conf_get_size (ORZ_CONF (dialog), &def_width, &def_height);
-  n_pos = orz_conf_get_tab (ORZ_CONF (dialog));
-  gtk_widget_destroy (dialog);
-  /* ja:ノートの位置 */
-  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
-}
-
-
 void
 command_conf (GtkWidget *widget,
               gpointer   user_data)
@@ -1086,21 +1087,25 @@ command_conf (GtkWidget *widget,
   GtkWidget *dialog;
 
   dialog = orz_conf_new ();
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (ORZ_CONF (dialog)->ok_button),
-                            "clicked", G_CALLBACK (command_conf_ok), dialog);
-  g_signal_connect_swapped (G_OBJECT (ORZ_CONF (dialog)->cancel_button),
-            "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  orz_conf_set_history (ORZ_CONF(dialog),
+  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+  orz_conf_set_history (ORZ_CONF (dialog),
                                 orz_history_get_num (ORZ_HISTORY (history)));
   orz_conf_set_newfile (ORZ_CONF (dialog), newfile);
   orz_conf_set_second (ORZ_CONF (dialog), second);
   orz_conf_set_size (ORZ_CONF (dialog), def_width, def_height);
   orz_conf_set_tab (ORZ_CONF (dialog), n_pos);
-  gtk_widget_show (dialog);
-  gtk_grab_add (dialog);
-  gtk_main ();
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      orz_history_set_num (ORZ_HISTORY (history),
+                                    orz_conf_get_history (ORZ_CONF (dialog)));
+      newfile = orz_conf_get_newfile (ORZ_CONF (dialog));
+      second = orz_conf_get_second (ORZ_CONF (dialog));
+      orz_conf_get_size (ORZ_CONF (dialog), &def_width, &def_height);
+      n_pos = orz_conf_get_tab (ORZ_CONF (dialog));
+      /* ja:ノートの位置 */
+      gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
+    }
+  gtk_widget_destroy (dialog);
 }
 
 
@@ -1108,7 +1113,7 @@ void
 command_format (GtkWidget *widget,
                 gpointer   user_data)
 {
-  ftype_dialog (FALSE);
+  ftype_dialog (GTK_WINDOW (window), FALSE);
 }
 
 
