@@ -26,7 +26,6 @@
 #include "sigmain.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
-#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 
@@ -52,7 +51,7 @@ file_open_text (const gchar *file,
   GError *error = NULL;
   GtkWidget *dialog;
 
-  charset = g_strsplit (tmaid->ft.charset, ",", G_MAXINT);
+  charset = g_strsplit (tmaid->ft.charset, ",", 0);
   g_free (tmaid->ft.charset);
   p = g_malloc0 (sizeof (LineBuffer));
   tmaid->max = 1;
@@ -101,15 +100,20 @@ file_open_text (const gchar *file,
       if (error && g_error_matches (error, G_CONVERT_ERROR,
                                                 G_CONVERT_ERROR_NO_CONVERSION))
         {
-          gchar *tmp;
-
           /* ja:キャラクターセットが無効 */
-          tmp = g_strdup_printf (_("Conversion from character encoding"
+          GtkWidget *dialog;
+
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("Conversion from character encoding"
                             " '%s' to 'UTF-8' is not supported"), charset[i]);
-          misc_message_box ("Text maid", tmp, 0, _("OK"), NULL);
-          g_free (tmp);
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
           for (j = 0; j < ftnum; j++)
             {
+              gchar *tmp;
+
               tmp = charuty_remove (ftype[j].charset, charset[i]);
               g_free (ftype[j].charset);
               ftype[j].charset = tmp ? tmp : g_strdup ("UTF-8");
@@ -350,7 +354,7 @@ file_open_edit (const gchar *file)
 #else /* not G_OS_WIN32 */
       tmaid->ft.crlf = MIN (ftype[0].crlf, 2);
 #endif /* not G_OS_WIN32 */
-      charset = g_strsplit (ftype[0].charset, ",", G_MAXINT);
+      charset = g_strsplit (ftype[0].charset, ",", 0);
       tmaid->ft.charset = g_strdup (charset[0]);
       g_strfreev (charset);
       /* ja:ファイルが0バイトのとき */
@@ -522,7 +526,7 @@ gboolean
 file_save_text (const gchar *file,
                 TmaidWindow *tmaid)
 {
-  gchar *buf = NULL, crlf[2], *ptr, *text, *outbuf;
+  gchar *buf = NULL, crlf[2], *ptr, *outbuf;
   gssize bytes_read_prev, bytes_read, bytes_written;
   gssize crlf_leng, leng, length = 0;
   FileIO *fio;
@@ -595,12 +599,14 @@ file_save_text (const gchar *file,
               g_clear_error (&error);
               gtk_grab_remove (dialog);
               gtk_widget_destroy (dialog);
-              text = g_strdup_printf
-                    (_("Conversion from character encoding"
-                    " 'UTF-8' to '%s' is not supported"), tmaid->ft.charset);
-              misc_message_box ("Text maid", text, 0, _("OK"), NULL);
-              g_free (text);
               g_free (buf);
+              dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                    GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                    _("Conversion from character encoding"
+                    " 'UTF-8' to '%s' is not supported"), tmaid->ft.charset);
+              gtk_dialog_run (GTK_DIALOG (dialog));
+              gtk_widget_destroy (dialog);
               return FALSE;
             }
           if (bytes_read <= 0)
@@ -624,10 +630,13 @@ file_save_text (const gchar *file,
                   default:
                     gtk_grab_remove (dialog);
                     gtk_widget_destroy (dialog);
-                    misc_message_box ("Text maid",
-                                _("Invalid byte sequence in conversion input"),
-                                                            0, _("OK"), NULL);
                     g_free (buf);
+                    dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("Invalid byte sequence in conversion input"));
+                    gtk_dialog_run (GTK_DIALOG (dialog));
+                    gtk_widget_destroy (dialog);
                     return FALSE;
                 }
               bytes_written = g_strlen (outbuf);
@@ -651,9 +660,13 @@ file_save_text (const gchar *file,
         {
           gtk_grab_remove (dialog);
           gtk_widget_destroy (dialog);
-          misc_message_box ("Text maid", _("Can not open file"),
-                                                            0, _("OK"), NULL);
           g_free (buf);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("Can not open file"));
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
           return FALSE;
         }
       ptr = buf;
@@ -666,9 +679,13 @@ file_save_text (const gchar *file,
             {
               gtk_grab_remove (dialog);
               gtk_widget_destroy (dialog);
-              misc_message_box ("Text maid", _("Can not write"),
-                                                            0, _("OK"), NULL);
               fileio_close (fio);
+              dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("Can not write"));
+              gtk_dialog_run (GTK_DIALOG (dialog));
+              gtk_widget_destroy (dialog);
               return FALSE;
             }
           length -= leng;
@@ -678,8 +695,13 @@ file_save_text (const gchar *file,
         {
           gtk_grab_remove (dialog);
           gtk_widget_destroy (dialog);
-          misc_message_box ("Text maid", "fclose", 0, _("OK"), NULL);
           g_free (buf);
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            "fileio_close");
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
           return FALSE;
         }
     }
