@@ -358,45 +358,22 @@ find_operation (TmaidWindow    *tmaid,
 * ja:検索ダイアログ関数群                                                     *
 *                                                                             *
 ******************************************************************************/
-static gboolean find_clicked_ok;
-static GtkWidget *dialog, *check, *combo, *radio1;
-
-
-/* ja:OKボタンが押された */
-static void
-find_dialog_clicked (GtkWidget  *widget,
-                     FindString *fd)
-{
-#if GTK_CHECK_VERSION(2,4,0)
-  fd->text = g_strdup
-                    (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child)));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  fd->text = g_strdup
-                (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry)));
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  fd->ignorecase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
-  fd->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
-  gtk_widget_destroy (dialog);
-  find_clicked_ok = TRUE;
-}
-
-
 /* ja:エントリーでリターンが押された */
 static void
-find_dialog_activate (GtkWidget  *widget,
-                      FindString *fd)
+find_dialog_activate (GtkWidget *widget,
+                      GtkWidget *dialog)
 {
   if (g_strlen (gtk_entry_get_text (GTK_ENTRY (widget))) > 0)
-    find_dialog_clicked (widget, fd);
+    gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 }
 
 
 /* ja:エントリーが変更された */
 static void
 find_dialog_changed (GtkWidget *widget,
-                     GtkWidget *button)
+                     GtkWidget *dialog)
 {
-  gtk_widget_set_sensitive (button,
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
                     g_strlen (gtk_entry_get_text (GTK_ENTRY (widget))) > 0);
 }
 
@@ -408,7 +385,7 @@ find_dialog_key_press (GtkWidget   *widget,
                        gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy(widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
@@ -419,28 +396,24 @@ find_dialog_key_press (GtkWidget   *widget,
 gboolean
 find_dialog (FindString *fd)
 {
+  gboolean result;
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  GtkWidget *radio0, *button0, *button1, *frame0, *frame1, *hbox, *tbox, *vbox;
+  GtkWidget *dialog, *check, *combo, *radio0, *radio1;
+  GtkWidget *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Find"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("Find"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_FIND, GTK_RESPONSE_ACCEPT,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (find_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  /* ja:ボタン */
-  button0 = gtk_button_new_with_mnemonic (_("_Find"));
-  button1 = gtk_button_new_with_label (_("Cancel"));
-  g_signal_connect (G_OBJECT (button0), "clicked",
-                                        G_CALLBACK (find_dialog_clicked), fd);
-  g_signal_connect_swapped (G_OBJECT (button1), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
   /* ja:チェックボタン */
   check = gtk_check_button_new_with_mnemonic (_("Enable _Case"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), fd->ignorecase);
@@ -456,9 +429,9 @@ find_dialog (FindString *fd)
                                                                         0, -1);
     }
   g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "activate",
-                                        G_CALLBACK (find_dialog_activate), fd);
+                                    G_CALLBACK (find_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "changed",
-                                    G_CALLBACK (find_dialog_changed), button0);
+                                    G_CALLBACK (find_dialog_changed), dialog);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; i < find_num; i++)
     glist = g_list_append (glist, find_text[i]);
@@ -474,9 +447,9 @@ find_dialog (FindString *fd)
       g_list_free (glist);
     }
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "activate",
-                                        G_CALLBACK (find_dialog_activate), fd);
+                                    G_CALLBACK (find_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
-                                    G_CALLBACK (find_dialog_changed), button0);
+                                    G_CALLBACK (find_dialog_changed), dialog);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_mnemonic (NULL, _("_Up"));
@@ -507,28 +480,35 @@ find_dialog (FindString *fd)
   gtk_box_pack_start (GTK_BOX (hbox), frame0, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), frame1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (tbox), hbox, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), tbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), tbox);
 
   /* ja:表示 */
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_widget_set_sensitive (button0,
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
     g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child))) > 0);
   gtk_widget_grab_focus (GTK_BIN (combo)->child);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  gtk_widget_set_sensitive (button0,
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
     g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry))) > 0);
   gtk_widget_grab_focus (GTK_COMBO (combo)->entry);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  find_clicked_ok = FALSE;
+  gtk_widget_show_all (tbox);
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+  result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT;
+  if (result)
+    {
+#if GTK_CHECK_VERSION(2,4,0)
+      fd->text = g_strdup
+                    (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child)));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+      fd->text = g_strdup
+                (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry)));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+      fd->ignorecase = gtk_toggle_button_get_active
+                                                (GTK_TOGGLE_BUTTON (check));
+      fd->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
+    }
+  gtk_widget_destroy (dialog);
 
-  return find_clicked_ok;
+  return result;
 }
