@@ -86,15 +86,13 @@ typedef struct _FileTypeDialog
   GtkWidget *button_up;
   GtkWidget *button_down;
   GtkWidget *button_edit;
-  GtkWidget *button_ok;
-  GtkWidget *button_cancel;
   GtkWidget *check;
 } FileTypeDialog;
 
 
 enum
 {
-  TARGET_TMAID_FTYPE
+  TARGET_GTK_TREE_MODEL_ROW
 };
 
 
@@ -120,8 +118,8 @@ ftype_dialog_changed (GtkTreeSelection *select,
       gtk_widget_set_sensitive (ftypedlg->button_up, ftypedlg->row > 0);
       gtk_widget_set_sensitive (ftypedlg->button_down, ftypedlg->row < i - 1);
       gtk_widget_set_sensitive (ftypedlg->button_edit, TRUE);
-      gtk_widget_set_sensitive (ftypedlg->button_ok,
-                                        ftypedlg->check || ftypedlg->edited);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                        GTK_RESPONSE_OK, ftypedlg->check || ftypedlg->edited);
     }
   else
     {
@@ -130,7 +128,8 @@ ftype_dialog_changed (GtkTreeSelection *select,
       gtk_widget_set_sensitive (ftypedlg->button_up, FALSE);
       gtk_widget_set_sensitive (ftypedlg->button_down, FALSE);
       gtk_widget_set_sensitive (ftypedlg->button_edit, FALSE);
-      gtk_widget_set_sensitive (ftypedlg->button_ok, ftypedlg->edited
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                            GTK_RESPONSE_OK, ftypedlg->edited
       || (ftypedlg->check
       && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ftypedlg->check))));
     }
@@ -157,7 +156,8 @@ ftype_dialog_clicked_new (GtkWidget      *widget,
       gtk_list_store_insert (ftypedlg->store, &iter, ftypedlg->row + 1);
       gtk_list_store_set (ftypedlg->store, &iter,
                                     0, ft_dst->text, 1, ft_dst, 2, FALSE, -1);
-      gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
       ftypedlg->edited = TRUE;
     }
 }
@@ -181,7 +181,8 @@ ftype_dialog_clicked_remove (GtkWidget      *widget,
       g_free (ft->ext);
       g_free (ft->font_name);
       g_free (ft);
-      gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
       ftypedlg->edited = TRUE;
     }
 }
@@ -214,7 +215,8 @@ ftype_dialog_clicked_up (GtkWidget      *widget,
       gtk_list_store_set (ftypedlg->store, &iter1,
                                         0, ft0->text, 1, ft0, 2, edited0, -1);
       gtk_tree_selection_select_iter (ftypedlg->select, &iter1);
-      gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
       ftypedlg->edited = TRUE;
 #if GTK_CHECK_VERSION(2,2,0)
@@ -251,7 +253,8 @@ ftype_dialog_clicked_down (GtkWidget      *widget,
       gtk_list_store_set (ftypedlg->store, &iter1,
                                         0, ft0->text, 1, ft0, 2, edited0, -1);
       gtk_tree_selection_select_iter (ftypedlg->select, &iter1);
-      gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
       ftypedlg->edited = TRUE;
 #if GTK_CHECK_VERSION(2,2,0)
@@ -274,82 +277,18 @@ ftype_dialog_clicked_edit (GtkWidget      *widget,
       FileType *ft;
 
       gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter, 1, &ft, -1);
-      if (property_dialog (ft))
+      if (property_dialog (GTK_WINDOW (ftypedlg->dialog), ft))
         {
           gtk_list_store_set (ftypedlg->store, &iter,
                                             0, ft->text, 1, ft, 2, TRUE, -1);
-          gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+          gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
           ftypedlg->edited = TRUE;
         }
     }
 }
 
 
-/* ja:OKが押されたとき */
-static void
-ftype_dialog_clicked_ok (GtkWidget      *widget,
-                         FileTypeDialog *ftypedlg)
-{
-  gint i;
-  GtkTreeIter iter;
-  FileType *ft;
-
-  for (i = 0; i < ftnum; i++)
-    {
-      g_free (ftype[i].text);
-      g_free (ftype[i].ext);
-      g_free (ftype[i].font_name);
-    }
-  g_free (ftype);
-  ftype = g_malloc0 (gtk_tree_model_iter_n_children
-                (GTK_TREE_MODEL (ftypedlg->store), NULL) * sizeof (FileType));
-  ftnum = 0;
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
-                                                        &iter, NULL, i); i++)
-    {
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter, 1, &ft, -1);
-      ftype_copy (ftype + ftnum++, ft);
-    }
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
-                                                        &iter, NULL, i); i++)
-    {
-      gboolean edited;
-
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter,
-                                                    1, &ft, 2, &edited, -1);
-      if (edited)
-        {
-          gint j;
-
-          /* ja:同一ファイルタイプをすべて変更 */
-          for (j = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; j >= 0; j--)
-            {
-              TmaidWindow *tmaid;
-
-              tmaid = orz_mdi_get_data (ORZ_MDI (mdi), j);
-              if (tmaid->ft.ft_id == ft->ft_id)
-                property_change (tmaid, ft);
-            }
-          charlist_renewal_all (ft->charset, -1);
-        }
-    }
-  if (ftypedlg->check
-        && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ftypedlg->check)))
-    ftypedlg->row = ftnum;
-  gtk_widget_destroy (ftypedlg->dialog);
-}
-
-
-/* ja:キャンセルが押されたとき */
-static void
-ftype_dialog_clicked_cancel (GtkWidget      *widget,
-                             FileTypeDialog *ftypedlg)
-{
-  ftypedlg->row = -1;
-  gtk_widget_destroy (ftypedlg->dialog);
-}
-
-
 /* ja:チェックボックスが変化したとき */
 void
 ftype_dialog_toggled (GtkToggleButton *togglebutton,
@@ -365,7 +304,8 @@ ftype_dialog_toggled (GtkToggleButton *togglebutton,
     {
       gtk_widget_set_sensitive (ftypedlg->tview, TRUE);
     }
-  gtk_widget_set_sensitive (ftypedlg->button_ok, TRUE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
   ftypedlg->edited = TRUE;
 }
 
@@ -392,7 +332,6 @@ ftype_dialog_destroy (GtkObject      *object,
           g_free (ft);
         }
     }
-  gtk_main_quit ();
 }
 
 
@@ -444,43 +383,52 @@ ftype_dialog_key_press (GtkWidget   *widget,
                         gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
 
 /*  ja:ファイルタイプダイアログを表示する
-    ind,TRUE:独立ファイルタイプあり,FALSE:なし
-    RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)                  */
+    parent,親ウインドウ
+       ind,TRUE:独立ファイルタイプあり,FALSE:なし
+       RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)               */
 gint
-ftype_dialog (gboolean ind)
+ftype_dialog (GtkWindow *parent,
+              gboolean   ind)
 {
   gint i;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkWidget *button, *scroll, *hbox, *vbox;
+  GtkWidget *scroll, *hbox, *vbox;
+  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW",
+    GTK_TARGET_SAME_APP | GTK_TARGET_SAME_WIDGET, TARGET_GTK_TREE_MODEL_ROW}};
   FileTypeDialog ftypedlg;
-  GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET | GTK_TARGET_SAME_WIDGET, TARGET_TMAID_FTYPE}};
 
   ftypedlg.edited = FALSE;
   ftypedlg.row = -1;
   /* ja:メインウインドウ */
-  ftypedlg.dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (ftypedlg.dialog),
-                            ind ? _("Associating File Type") : _("File Type"));
+  ftypedlg.dialog = gtk_dialog_new_with_buttons
+                            (ind ? _("Associating File Type") : _("File Type"),
+                            parent,
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   gtk_window_set_default_size (GTK_WINDOW (ftypedlg.dialog), 320, 240);
   g_signal_connect_after (G_OBJECT (ftypedlg.dialog), "key-press-event",
                                 G_CALLBACK (ftype_dialog_key_press), NULL);
   g_signal_connect (G_OBJECT (ftypedlg.dialog), "destroy",
                                 G_CALLBACK (ftype_dialog_destroy), &ftypedlg);
   /* ja:ボタン */
-  ftypedlg.button_new = gtk_button_new_with_mnemonic (_("_New"));
-  ftypedlg.button_remove = gtk_button_new_with_mnemonic (_("De_lete"));
-  ftypedlg.button_up = gtk_button_new_with_mnemonic (_("_Up"));
-  ftypedlg.button_down = gtk_button_new_with_mnemonic (_("_Down"));
+  ftypedlg.button_new = gtk_button_new_from_stock (GTK_STOCK_NEW);
+  ftypedlg.button_remove = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  ftypedlg.button_up = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
+  ftypedlg.button_down = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
+#if GTK_CHECK_VERSION(2,6,0)
+  ftypedlg.button_edit = gtk_button_new_from_stock (GTK_STOCK_EDIT);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
   ftypedlg.button_edit = gtk_button_new_with_mnemonic (_("_Edit"));
-  ftypedlg.button_ok = gtk_button_new_with_label (_("OK"));
-  button = gtk_button_new_with_label (_("Cancel"));
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
   g_signal_connect (G_OBJECT (ftypedlg.button_new), "clicked",
                         G_CALLBACK (ftype_dialog_clicked_new), &ftypedlg);
   g_signal_connect (G_OBJECT (ftypedlg.button_remove), "clicked",
@@ -491,17 +439,11 @@ ftype_dialog (gboolean ind)
                         G_CALLBACK (ftype_dialog_clicked_down), &ftypedlg);
   g_signal_connect (G_OBJECT (ftypedlg.button_edit), "clicked",
                         G_CALLBACK (ftype_dialog_clicked_edit), &ftypedlg);
-  g_signal_connect (G_OBJECT (ftypedlg.button_ok), "clicked",
-                        G_CALLBACK (ftype_dialog_clicked_ok), &ftypedlg);
-  g_signal_connect (G_OBJECT (button), "clicked",
-                        G_CALLBACK (ftype_dialog_clicked_cancel), &ftypedlg);
   GTK_WIDGET_SET_FLAGS (ftypedlg.button_new, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (ftypedlg.button_remove, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (ftypedlg.button_up, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (ftypedlg.button_down, GTK_CAN_DEFAULT);
   GTK_WIDGET_SET_FLAGS (ftypedlg.button_edit, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_ok, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   /* ja:チェックボタン */
   if (ind)
     {
@@ -566,10 +508,8 @@ ftype_dialog (gboolean ind)
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_up, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_down, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_edit, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), ftypedlg.button_ok, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (ftypedlg.dialog), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (ftypedlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_set_sensitive (ftypedlg.button_new, FALSE);
@@ -577,13 +517,64 @@ ftype_dialog (gboolean ind)
   gtk_widget_set_sensitive (ftypedlg.button_up, FALSE);
   gtk_widget_set_sensitive (ftypedlg.button_down, FALSE);
   gtk_widget_set_sensitive (ftypedlg.button_edit, FALSE);
-  gtk_widget_set_sensitive (ftypedlg.button_ok, FALSE);
-  gtk_widget_grab_focus (button);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg.dialog),
+                                                    GTK_RESPONSE_OK, FALSE);
+  gtk_widget_show_all (vbox);
 
-  gtk_window_set_policy (GTK_WINDOW (ftypedlg.dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (ftypedlg.dialog);
-  gtk_widget_show_all (ftypedlg.dialog);
-  gtk_main ();
+  if (gtk_dialog_run (GTK_DIALOG (ftypedlg.dialog)) == GTK_RESPONSE_OK)
+    {
+      GtkTreeIter iter;
+      FileType *ft;
+
+      for (i = 0; i < ftnum; i++)
+        {
+          g_free (ftype[i].text);
+          g_free (ftype[i].ext);
+          g_free (ftype[i].font_name);
+        }
+      g_free (ftype);
+      ftype = g_malloc0 (gtk_tree_model_iter_n_children
+                (GTK_TREE_MODEL (ftypedlg.store), NULL) * sizeof (FileType));
+      ftnum = 0;
+      for (i = 0; gtk_tree_model_iter_nth_child
+                        (GTK_TREE_MODEL (ftypedlg.store), &iter, NULL, i); i++)
+        {
+          gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg.store), &iter,
+                                                                1, &ft, -1);
+          ftype_copy (ftype + ftnum++, ft);
+        }
+      for (i = 0; gtk_tree_model_iter_nth_child
+                        (GTK_TREE_MODEL (ftypedlg.store), &iter, NULL, i); i++)
+        {
+          gboolean edited;
+
+          gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg.store), &iter,
+                                                    1, &ft, 2, &edited, -1);
+          if (edited)
+            {
+              gint j;
+
+              /* ja:同一ファイルタイプをすべて変更 */
+              for (j = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; j >= 0; j--)
+                {
+                  TmaidWindow *tmaid;
+
+                  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), j);
+                  if (tmaid->ft.ft_id == ft->ft_id)
+                    property_change (tmaid, ft);
+                }
+              charlist_renewal_all (ft->charset, -1);
+            }
+        }
+      if (ftypedlg.check
+        && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ftypedlg.check)))
+        ftypedlg.row = ftnum;
+    }
+  else
+    {
+      ftypedlg.row = -1;
+    }
+  gtk_widget_destroy (ftypedlg.dialog);
 
   return ftypedlg.row;
 }
