@@ -34,10 +34,12 @@ extern "C" {
 *                                                                             *
 ******************************************************************************/
 /*  ja:ファイルタイプダイアログを表示する
-    ind,TRUE:独立ファイルタイプあり,FALSE:なし
-    RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)                  */
+    parent,親ウインドウ
+       ind,TRUE:独立ファイルタイプあり,FALSE:なし
+       RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)               */
 gint
-ftype_dialog (gboolean ind);
+ftype_dialog (GtkWindow *parent,
+              gboolean   ind);
 
 
 #ifdef __cplusplus
