@@ -141,7 +141,6 @@ property_change (TmaidWindow *tmaid,
 ******************************************************************************/
 typedef struct _PropertyDialog
 {
-  gboolean clicked_ok, color_list[12];
   gchar *charset_list;
 #if ! GTK_CHECK_VERSION(2,4,0)
   gchar *font_name;
@@ -150,17 +149,10 @@ typedef struct _PropertyDialog
   GdkColor gdk_color[12];
   GtkListStore *store;
   GtkWidget *dialog;
-  GtkWidget *dialog_color;
-  GtkWidget *dialog_charlist;
-#if ! GTK_CHECK_VERSION(2,4,0)
-  GtkWidget *dialog_font;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
   GtkWidget *button_color;
-  GtkWidget *button_auto;
 #if GTK_CHECK_VERSION(2,4,0)
   GtkWidget *button_font;
 #endif /* GTK_CHECK_VERSION(2,4,0) */
-  GtkWidget *button_ok;
   GtkWidget *charset;
   GtkWidget *check_gline;     /* ja:TRUE:グリッド線表示 */
   GtkWidget *check_space;     /* ja:TRUE:スペースを灰色の四角で表示 */
@@ -192,7 +184,6 @@ typedef struct _PropertyDialog
   GtkWidget *spin_margin;
   GtkWidget *spin_tab;
   GtkWidget *tview;
-  FileType *ft;
 } PropertyDialog;
 
 
@@ -201,7 +192,8 @@ static void
 property_dialog_ok_sensitive (GtkWidget      *widget,
                               PropertyDialog *propdlg)
 {
-  gtk_widget_set_sensitive (propdlg->button_ok,
+  gtk_dialog_set_response_sensitive
+                                (GTK_DIALOG (propdlg->dialog), GTK_RESPONSE_OK,
     (!propdlg->entry_text
         || g_strlen (gtk_entry_get_text (GTK_ENTRY (propdlg->entry_text))) > 0)
     && (!propdlg->entry_ext
@@ -266,95 +258,64 @@ property_dialog_changed (GtkTreeSelection *select,
 }
 
 
-/* ja:色の設定でOKが押されたとき */
-static void
-property_dialog_clicked_color_ok (GtkWidget      *widget,
-                                  PropertyDialog *propdlg)
-{
-  gchar *xpm[18];
-  gint i;
-  gdouble color[4];
-
-  gtk_color_selection_get_color (GTK_COLOR_SELECTION
-        (GTK_COLOR_SELECTION_DIALOG (propdlg->dialog_color)->colorsel), color);
-  xpm[0] = "24 16 1 1";
-  for (i = 2; i < 18; i++)
-    xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
-  for (i = 0; i < 12; i++)
-    {
-      GtkTreeIter iter;
-
-      if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
-                                                                &iter, NULL, i)
-        && gtk_tree_selection_iter_is_selected
-        (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)), &iter))
-        {
-          propdlg->gdk_color[i].red = color[0] * 0xffff;
-          propdlg->gdk_color[i].green = color[1] * 0xffff;
-          propdlg->gdk_color[i].blue = color[2] * 0xffff;
-          xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
-                                            propdlg->gdk_color[i].red / 256,
-                                            propdlg->gdk_color[i].green / 256,
-                                            propdlg->gdk_color[i].blue / 256);
-          gtk_list_store_set (propdlg->store, &iter,
-                    0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm), -1);
-          g_free (xpm[1]);
-        }
-    }
-  property_dialog_ok_sensitive (widget, propdlg);
-  gtk_widget_destroy (propdlg->dialog_color);
-}
-
-
 /* ja:色の設定ボタンが押された */
 static void
 property_dialog_clicked_color (GtkWidget      *widget,
                                PropertyDialog *propdlg)
 {
   gint i;
+  gdouble color[4];
+  GtkTreeIter iter;
+  GtkWidget *dialog;
 
-  propdlg->dialog_color
-                = gtk_color_selection_dialog_new (_("Color Configuration"));
-  g_signal_connect (G_OBJECT (propdlg->dialog_color), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT
-        (GTK_COLOR_SELECTION_DIALOG (propdlg->dialog_color)->ok_button),
-        "clicked",G_CALLBACK (property_dialog_clicked_color_ok), propdlg);
-  g_signal_connect_swapped (G_OBJECT (GTK_COLOR_SELECTION_DIALOG
-                                    (propdlg->dialog_color)->cancel_button),
-                                    "clicked", G_CALLBACK (gtk_widget_destroy),
-                                            G_OBJECT (propdlg->dialog_color));
+  dialog = gtk_color_selection_dialog_new (_("Color Configuration"));
+  gtk_window_set_transient_for (GTK_WINDOW (dialog),
+                                                GTK_WINDOW (propdlg->dialog));
   for (i = 0; i < 12; i++)
-    if (propdlg->color_list[i])
+    if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
+                                                                &iter, NULL, i)
+            && gtk_tree_selection_iter_is_selected
+                (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
+                                                                        &iter))
       {
-        gdouble color[4];
-
         color[0] = (gdouble)propdlg->gdk_color[i].red / 0xffff;
         color[1] = (gdouble)propdlg->gdk_color[i].green / 0xffff;
         color[2] = (gdouble)propdlg->gdk_color[i].blue / 0xffff;
         color[3] = 0;
         gtk_color_selection_set_color (GTK_COLOR_SELECTION
-                (GTK_COLOR_SELECTION_DIALOG (propdlg->dialog_color)->colorsel),
-                                                                        color);
+                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
         break;
       }
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      gchar *xpm[18];
 
-  gtk_widget_show (propdlg->dialog_color);
-  gtk_grab_add (propdlg->dialog_color);
-  gtk_main ();
-}
-
-
-/* ja:文字符号化方式の設定でOKが押されたとき */
-static void
-property_dialog_clicked_charlist_ok (GtkWidget      *widget,
-                                     PropertyDialog *propdlg)
-{
-  g_free (propdlg->charset_list);
-  propdlg->charset_list
-        = orz_charlist_get_charlist (ORZ_CHARLIST (propdlg->dialog_charlist));
-  property_dialog_ok_sensitive (widget, propdlg);
-  gtk_widget_destroy (propdlg->dialog_charlist);
+      gtk_color_selection_get_color (GTK_COLOR_SELECTION
+                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+      xpm[0] = "24 16 1 1";
+      for (i = 2; i < 18; i++)
+        xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
+      for (i = 0; i < 12; i++)
+        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
+                                                                &iter, NULL, i)
+            && gtk_tree_selection_iter_is_selected
+                (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
+                                                                        &iter))
+          {
+            propdlg->gdk_color[i].red = color[0] * 0xffff;
+            propdlg->gdk_color[i].green = color[1] * 0xffff;
+            propdlg->gdk_color[i].blue = color[2] * 0xffff;
+            xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
+                                            propdlg->gdk_color[i].red / 256,
+                                            propdlg->gdk_color[i].green / 256,
+                                            propdlg->gdk_color[i].blue / 256);
+            gtk_list_store_set (propdlg->store, &iter,
+                    0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm), -1);
+            g_free (xpm[1]);
+          }
+      property_dialog_ok_sensitive (widget, propdlg);
+    }
+  gtk_widget_destroy (dialog);
 }
 
 
@@ -364,69 +325,55 @@ property_dialog_clicked_charlist (GtkWidget      *widget,
                                   PropertyDialog *propdlg)
 {
   gint i;
+  GtkWidget *dialog;
 
-  propdlg->dialog_charlist = orz_charlist_new ();
-  g_signal_connect (G_OBJECT (propdlg->dialog_charlist), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect
-                (G_OBJECT (ORZ_CHARLIST (propdlg->dialog_charlist)->ok_button),
-        "clicked", G_CALLBACK (property_dialog_clicked_charlist_ok), propdlg);
-  g_signal_connect_swapped
-    (G_OBJECT (ORZ_CHARLIST (propdlg->dialog_charlist)->cancel_button),
-                                    "clicked", G_CALLBACK (gtk_widget_destroy),
-                                        GTK_OBJECT (propdlg->dialog_charlist));
-  orz_charlist_set_charlist (ORZ_CHARLIST (propdlg->dialog_charlist),
-                                                        propdlg->charset_list);
+  dialog = orz_charlist_new ();
+  gtk_window_set_transient_for (GTK_WINDOW (dialog),
+                                                GTK_WINDOW (propdlg->dialog));
+  orz_charlist_set_charlist (ORZ_CHARLIST (dialog), propdlg->charset_list);
   for (i = 0; i < ftnum; i++)
-    orz_charlist_add_candidate (ORZ_CHARLIST (propdlg->dialog_charlist),
-                                                            ftype[i].charset);
-  gtk_widget_show (propdlg->dialog_charlist);
-  gtk_grab_add (propdlg->dialog_charlist);
-  gtk_main ();
+    orz_charlist_add_candidate (ORZ_CHARLIST (dialog), ftype[i].charset);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      g_free (propdlg->charset_list);
+      propdlg->charset_list
+                        = orz_charlist_get_charlist (ORZ_CHARLIST (dialog));
+      property_dialog_ok_sensitive (widget, propdlg);
+    }
+  gtk_widget_destroy (dialog);
 }
 
 
 #if ! GTK_CHECK_VERSION(2,4,0)
-/* ja:フォントの設定でOKが押されたとき */
-static void
-property_dialog_clicked_font_ok (GtkWidget      *widget,
-                                 PropertyDialog *propdlg)
-{
-  gchar *name;
-
-  name = gtk_font_selection_dialog_get_font_name
-                            (GTK_FONT_SELECTION_DIALOG (propdlg->dialog_font));
-  if (name && name[0] != '\0')
-    {
-      g_free (propdlg->font_name);
-      propdlg->font_name = name;
-      property_dialog_ok_sensitive (widget, propdlg);
-    }
-  gtk_widget_destroy (propdlg->dialog_font);
-}
-
-
 /* ja:フォントボタンが押された */
 static void
 property_dialog_clicked_font (GtkWidget      *widget,
                               PropertyDialog *propdlg)
 {
-  propdlg->dialog_font = gtk_font_selection_dialog_new (_("Font"));
-  g_signal_connect (G_OBJECT (propdlg->dialog_font), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT
-            (GTK_FONT_SELECTION_DIALOG (propdlg->dialog_font)->ok_button),
-            "clicked", G_CALLBACK (property_dialog_clicked_font_ok), propdlg);
-  g_signal_connect_swapped (G_OBJECT (GTK_FONT_SELECTION_DIALOG
-                                        (propdlg->dialog_font)->cancel_button),
-                                    "clicked", G_CALLBACK (gtk_widget_destroy),
-                                            G_OBJECT (propdlg->dialog_font));
+  GtkWidget *dialog;
+
+  dialog = gtk_font_selection_dialog_new (_("Font"));
   if (propdlg->font_name)
     gtk_font_selection_dialog_set_font_name
-        (GTK_FONT_SELECTION_DIALOG (propdlg->dialog_font), propdlg->font_name);
-  gtk_widget_show (propdlg->dialog_font);
-  gtk_grab_add (propdlg->dialog_font);
-  gtk_main ();
+        (GTK_FONT_SELECTION_DIALOG (dialog), propdlg->font_name);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      gchar *name;
+
+      name = gtk_font_selection_dialog_get_font_name
+                                        (GTK_FONT_SELECTION_DIALOG (dialog));
+      if (name && name[0] != '\0')
+        {
+          g_free (propdlg->font_name);
+          propdlg->font_name = name;
+          property_dialog_ok_sensitive (widget, propdlg);
+        }
+      else
+        {
+          g_free (name);
+        }
+    }
+  gtk_widget_destroy (dialog);
 }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 
@@ -438,9 +385,13 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
 {
   gint pos;
 
-  pos = ftype_dialog (TRUE);
+  pos = ftype_dialog (GTK_WINDOW (propdlg->dialog), TRUE);
   if (0 <= pos && pos < ftnum)
     {
+      gchar *xpm[18];
+      gint i;
+      GtkTreeIter iter;
+
       propdlg->ft_id = ftype[pos].ft_id;
       gtk_label_set_text (GTK_LABEL (propdlg->label), ftype[pos].text);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (propdlg->check_gline),
@@ -502,6 +453,21 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (propdlg->spin_tab),
                                                             ftype[pos].tab);
       g_memmove (propdlg->gdk_color, ftype[pos].color, sizeof (GdkColor) * 12);
+      xpm[0] = "24 16 1 1";
+      for (i = 2; i < 18; i++)
+        xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
+      for (i = 0; i < 12; i++)
+        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
+                                                            &iter, NULL, i))
+          {
+            xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
+                                            propdlg->gdk_color[i].red / 256,
+                                            propdlg->gdk_color[i].green / 256,
+                                            propdlg->gdk_color[i].blue / 256);
+            gtk_list_store_set (propdlg->store, &iter,
+                    0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm), -1);
+            g_free (xpm[1]);
+          }
 #if GTK_CHECK_VERSION(2,4,0)
       gtk_font_button_set_font_name (GTK_FONT_BUTTON (propdlg->button_font),
                                                         ftype[pos].font_name);
@@ -509,7 +475,8 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
       g_free (propdlg->font_name);
       propdlg->font_name = g_strdup (ftype[pos].font_name);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-      gtk_widget_set_sensitive (propdlg->button_ok, TRUE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (propdlg->dialog),
+                                                        GTK_RESPONSE_OK, TRUE);
     }
   else if (pos >= ftnum)
     {
@@ -521,132 +488,18 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
 }
 
 
-/* ja:OKボタンが押された */
-static void
-property_dialog_clicked_ok (GtkWidget      *widget,
-                            PropertyDialog *propdlg)
-{
-  propdlg->ft->ft_id = propdlg->ft_id;
-  if (propdlg->entry_text)
-    {
-      g_free (propdlg->ft->text);
-      propdlg->ft->text
-            = g_strdup (gtk_entry_get_text (GTK_ENTRY (propdlg->entry_text)));
-    }
-  if (propdlg->entry_ext)
-    {
-      g_free (propdlg->ft->ext);
-      propdlg->ft->ext
-            = g_strdup (gtk_entry_get_text (GTK_ENTRY (propdlg->entry_ext)));
-    }
-  propdlg->ft->margin = gtk_spin_button_get_value_as_int
-                            (GTK_SPIN_BUTTON (propdlg->spin_margin));
-  propdlg->ft->tab = gtk_spin_button_get_value_as_int
-                            (GTK_SPIN_BUTTON (propdlg->spin_tab));
-  propdlg->ft->gline = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_gline));
-  propdlg->ft->space = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_space));
-  propdlg->ft->nline = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_nline));
-  propdlg->ft->mline = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_mline));
-  propdlg->ft->limit = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_limit));
-  propdlg->ft->code = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_code));
-  propdlg->ft->uline = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_uline));
-  propdlg->ft->vline = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_vline));
-  propdlg->ft->autoindent = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_autoindent));
-  propdlg->ft->tabconv = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_tabconv));
-  propdlg->ft->eof = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_eof));
-  propdlg->ft->overwrite = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_overwrite));
-  propdlg->ft->syscol = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_syscol));
-  if (propdlg->check_html)
-    propdlg->ft->html = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_html));
-  if (propdlg->check_esc)
-    propdlg->ft->esc = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_esc));
-  if (propdlg->check_associate)
-    propdlg->ft->associate = gtk_toggle_button_get_active
-                            (GTK_TOGGLE_BUTTON (propdlg->check_associate));
-  if (gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg->radio_question)))
-    propdlg->ft->writemode = 1;
-  else if (gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg->radio_decimal)))
-    propdlg->ft->writemode = 2;
-  else if (gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg->radio_hex)))
-    propdlg->ft->writemode = 3;
-  else if (gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg->radio_escape)))
-    propdlg->ft->writemode = 4;
-  else
-    propdlg->ft->writemode = 0;
-  propdlg->ft->hexcase = gtk_toggle_button_get_active
-                                (GTK_TOGGLE_BUTTON (propdlg->radio_upper));
-  if (propdlg->combo)
-#if GTK_CHECK_VERSION(2,4,0)
-    propdlg->ft->crlf = gtk_combo_box_get_active
-                                            (GTK_COMBO_BOX (propdlg->combo));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-    {
-      const gchar *text;
-      GList *glist;
-
-      text = gtk_entry_get_text
-                            (GTK_ENTRY (GTK_COMBO (propdlg->combo)->entry));
-      glist = gtk_container_children
-                            (GTK_CONTAINER (GTK_COMBO (propdlg->combo)->list));
-      for (propdlg->ft->crlf = g_list_length (glist) - 1;
-                                propdlg->ft->crlf >= 0; propdlg->ft->crlf--)
-        if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child (GTK_BIN
-                (g_list_nth_data (glist, propdlg->ft->crlf))))), text) == 0)
-          break;
-      g_list_free (glist);
-      if (propdlg->ft->crlf < 0)
-        propdlg->ft->crlf = 0;
-    }
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  g_free (propdlg->ft->charset);
-  if (propdlg->charset)
-    propdlg->ft->charset
-                    = orz_charset_get_charset (ORZ_CHARSET (propdlg->charset));
-  if (propdlg->button_auto)
-    {
-      propdlg->ft->charset = propdlg->charset_list;
-      propdlg->charset_list = NULL;
-    }
-  g_memmove (propdlg->ft->color, propdlg->gdk_color, sizeof (GdkColor) * 12);
-  g_free (propdlg->ft->font_name);
-#if GTK_CHECK_VERSION(2,4,0)
-  propdlg->ft->font_name = g_strdup (gtk_font_button_get_font_name
-                                    (GTK_FONT_BUTTON (propdlg->button_font)));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  propdlg->ft->font_name = propdlg->font_name;
-  propdlg->font_name = NULL;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  gtk_widget_destroy (propdlg->dialog);
-  propdlg->clicked_ok = TRUE;
-}
-
-
 /* ja:スピンボタン/コンボボックスでリターンが押された */
 static void
 property_dialog_activate (GtkWidget      *widget,
                           PropertyDialog *propdlg)
 {
-  if (GTK_WIDGET_IS_SENSITIVE (propdlg->button_ok))
-    property_dialog_clicked_ok (widget, propdlg);
+  if ((!propdlg->entry_text
+        || g_strlen (gtk_entry_get_text (GTK_ENTRY (propdlg->entry_text))) > 0)
+    && (!propdlg->entry_ext
+        || g_strlen (gtk_entry_get_text (GTK_ENTRY (propdlg->entry_ext))) > 0)
+    && (!propdlg->charset
+        || orz_charset_is_valid (ORZ_CHARSET (propdlg->charset))))
+    gtk_dialog_response (GTK_DIALOG (propdlg->dialog), GTK_RESPONSE_OK);
 }
 
 
@@ -657,17 +510,20 @@ property_dialog_key_press (GtkWidget   *widget,
                            gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
 
 /*  ja:プロパティダイアログ表示
-     ft,ファイルタイプ
-    RET,TRUE:OK,FALSE:Cancel                                                */
+    parent,親ウインドウ
+        ft,ファイルタイプ
+       RET,TRUE:OK,FALSE:Cancel                                             */
 gboolean
-property_dialog (FileType *ft)
+property_dialog (GtkWindow *parent,
+                 FileType  *ft)
 {
+  gboolean result;
   gchar *xpm[18];
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
@@ -677,7 +533,7 @@ property_dialog (FileType *ft)
   GtkTreeIter iter;
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
-  GtkWidget *button_associated, *button_cancel, *scroll, *frame_label;
+  GtkWidget *button_associated, *button_auto, *scroll, *label;
   GtkWidget *hbox, *tbox, *vbox;
   GtkWidget *frame0, *frame1, *frame2, *frame3, *frame4, *frame5, *frame6;
 #if ! GTK_CHECK_VERSION(2,4,0)
@@ -692,13 +548,16 @@ property_dialog (FileType *ft)
   PropertyDialog propdlg;
 
   /* ja:メインウインドウ */
-  propdlg.dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (propdlg.dialog), !ft->text || !ft->ext
-                                ? _("Property") : _("Details of File Type"));
+  propdlg.dialog = gtk_dialog_new_with_buttons
+                            (!ft->text || !ft->ext
+                                ? _("Property") : _("Details of File Type"),
+                            parent,
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   g_signal_connect_after (G_OBJECT (propdlg.dialog), "key-press-event",
                                 G_CALLBACK (property_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (propdlg.dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
   /* ja:ボタン */
   propdlg.button_color = gtk_button_new_with_label (_("Palette"));
 #if GTK_CHECK_VERSION(2,4,0)
@@ -706,8 +565,6 @@ property_dialog (FileType *ft)
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   button_font = gtk_button_new_with_mnemonic (_("_Font"));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  propdlg.button_ok = gtk_button_new_with_label (_("OK"));
-  button_cancel = gtk_button_new_with_label (_("Cancel"));
   g_signal_connect (G_OBJECT (propdlg.button_color), "clicked",
                         G_CALLBACK (property_dialog_clicked_color), &propdlg);
 #if GTK_CHECK_VERSION(2,4,0)
@@ -717,28 +574,21 @@ property_dialog (FileType *ft)
   g_signal_connect (G_OBJECT (button_font), "clicked",
                         G_CALLBACK (property_dialog_clicked_font), &propdlg);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  g_signal_connect (G_OBJECT (propdlg.button_ok), "clicked",
-                        G_CALLBACK (property_dialog_clicked_ok), &propdlg);
-  g_signal_connect_swapped (G_OBJECT (button_cancel), "clicked",
-                G_CALLBACK (gtk_widget_destroy), G_OBJECT (propdlg.dialog));
-  GTK_WIDGET_SET_FLAGS (propdlg.button_ok, GTK_CAN_DEFAULT);
 #if GTK_CHECK_VERSION(2,4,0)
   GTK_WIDGET_SET_FLAGS (propdlg.button_font, GTK_CAN_DEFAULT);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   GTK_WIDGET_SET_FLAGS (button_font, GTK_CAN_DEFAULT);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  GTK_WIDGET_SET_FLAGS (propdlg.button_ok, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button_cancel, GTK_CAN_DEFAULT);
   if (ft->text && ft->ext)
     {
-      propdlg.button_auto = gtk_button_new_with_label (_("Auto Negotiation"));
-      g_signal_connect (G_OBJECT (propdlg.button_auto), "clicked",
+      button_auto = gtk_button_new_with_label (_("Auto Negotiation"));
+      g_signal_connect (G_OBJECT (button_auto), "clicked",
                     G_CALLBACK (property_dialog_clicked_charlist), &propdlg);
-      GTK_WIDGET_SET_FLAGS (propdlg.button_auto, GTK_CAN_DEFAULT);
+      GTK_WIDGET_SET_FLAGS (button_auto, GTK_CAN_DEFAULT);
     }
   else
     {
-      propdlg.button_auto = NULL;
+      button_auto = NULL;
     }
   if (!ft->text && !ft->ext)
     {
@@ -1034,9 +884,9 @@ property_dialog (FileType *ft)
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
   /* ja:フレームとボックス */
   frame0 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame0));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label), _("_Display"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), propdlg.check_gline);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame0));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Display"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_gline);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), SPACING);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.check_gline, TRUE, TRUE, 0);
@@ -1045,10 +895,9 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame0), hbox);
 
   frame1 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame1));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label),
-                                      _("_Right Margin"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), propdlg.spin_margin);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame1));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Right Margin"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.spin_margin);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), SPACING);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.spin_margin, TRUE, TRUE, 0);
@@ -1057,9 +906,9 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame1), hbox);
 
   frame2 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame2));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label), _("_Tab"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), propdlg.spin_tab);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame2));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Tab"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.spin_tab);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), SPACING);
   gtk_box_pack_start (GTK_BOX (hbox), propdlg.spin_tab, TRUE, TRUE, 0);
@@ -1069,10 +918,9 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame2), hbox);
 
   frame3 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame3));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label), _("Ed_it"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label),
-                                                    propdlg.check_autoindent);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame3));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("Ed_it"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_autoindent);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), SPACING);
   gtk_box_pack_start (GTK_BOX(hbox),
@@ -1081,9 +929,9 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame3), hbox);
 
   frame4 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame4));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label), _("_Save"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), propdlg.check_eof);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame4));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Save"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_eof);
   tbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (tbox), SPACING);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -1106,10 +954,9 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame4), tbox);
 
   frame5 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame5));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label), _("_Color"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label),
-                                                        propdlg.check_syscol);
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame5));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("_Color"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.check_syscol);
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
@@ -1120,22 +967,22 @@ property_dialog (FileType *ft)
   gtk_container_add (GTK_CONTAINER (frame5), vbox);
 
   frame6 = gtk_frame_new ("");
-  frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame6));
-  gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label),
+  label = gtk_frame_get_label_widget (GTK_FRAME (frame6));
+  gtk_label_set_text_with_mnemonic (GTK_LABEL (label),
                                                     _("Character _Encoding"));
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), propdlg.combo);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), propdlg.combo);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label),
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label),
                                             GTK_COMBO (propdlg.combo)->entry);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), propdlg.combo, FALSE, FALSE, 0);
-  if (propdlg.button_auto)
+  if (button_auto)
     {
       hbox = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_end (GTK_BOX (hbox), propdlg.button_auto, FALSE, FALSE, 0);
+      gtk_box_pack_end (GTK_BOX (hbox), button_auto, FALSE, FALSE, 0);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     }
   if (propdlg.charset)
@@ -1193,38 +1040,142 @@ property_dialog (FileType *ft)
   if (propdlg.check_associate)
     gtk_box_pack_start (GTK_BOX (hbox),
                                     propdlg.check_associate, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button_cancel, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), propdlg.button_ok, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  gtk_container_add (GTK_CONTAINER (propdlg.dialog), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (propdlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_set_sensitive (propdlg.button_color, FALSE);
-  gtk_widget_set_sensitive (propdlg.button_ok, FALSE);
   gtk_widget_set_sensitive (propdlg.radio_upper, ft->writemode >= 3);
   gtk_widget_set_sensitive (propdlg.radio_lower, ft->writemode >= 3);
   gtk_widget_set_sensitive (propdlg.tview, !ft->syscol);
-  gtk_widget_grab_focus (button_cancel);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (propdlg.dialog),
+                                                    GTK_RESPONSE_OK, FALSE);
+  gtk_widget_show_all (vbox);
 
   propdlg.ft_id = ft->ft_id;
-  propdlg.ft = ft;
   g_memmove (propdlg.gdk_color, ft->color, sizeof (GdkColor) * 12);
-  propdlg.charset_list = propdlg.button_auto ? g_strdup (ft->charset) : NULL;
+  propdlg.charset_list = button_auto ? g_strdup (ft->charset) : NULL;
 #if ! GTK_CHECK_VERSION(2,4,0)
   propdlg.font_name = g_strdup (ft->font_name);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  propdlg.clicked_ok = FALSE;
 
-  gtk_window_set_policy (GTK_WINDOW (propdlg.dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (propdlg.dialog);
-  gtk_widget_show_all (propdlg.dialog);
-  gtk_main ();
+  result = gtk_dialog_run (GTK_DIALOG (propdlg.dialog)) == GTK_RESPONSE_OK;
+  if (result)
+    {
+      ft->ft_id = propdlg.ft_id;
+      if (propdlg.entry_text)
+        {
+          g_free (ft->text);
+          ft->text
+            = g_strdup (gtk_entry_get_text (GTK_ENTRY (propdlg.entry_text)));
+        }
+      if (propdlg.entry_ext)
+        {
+          g_free (ft->ext);
+          ft->ext
+            = g_strdup (gtk_entry_get_text (GTK_ENTRY (propdlg.entry_ext)));
+        }
+      ft->margin = gtk_spin_button_get_value_as_int
+                                (GTK_SPIN_BUTTON (propdlg.spin_margin));
+      ft->tab = gtk_spin_button_get_value_as_int
+                                (GTK_SPIN_BUTTON (propdlg.spin_tab));
+      ft->gline = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_gline));
+      ft->space = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_space));
+      ft->nline = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_nline));
+      ft->mline = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_mline));
+      ft->limit = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_limit));
+      ft->code = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_code));
+      ft->uline = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_uline));
+      ft->vline = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_vline));
+      ft->autoindent = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_autoindent));
+      ft->tabconv = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_tabconv));
+      ft->eof = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_eof));
+      ft->overwrite = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_overwrite));
+      ft->syscol = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_syscol));
+      if (propdlg.check_html)
+        ft->html = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_html));
+      if (propdlg.check_esc)
+        ft->esc = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_esc));
+      if (propdlg.check_associate)
+        ft->associate = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.check_associate));
+      if (gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.radio_question)))
+        ft->writemode = 1;
+      else if (gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.radio_decimal)))
+        ft->writemode = 2;
+      else if (gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.radio_hex)))
+        ft->writemode = 3;
+      else if (gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.radio_escape)))
+        ft->writemode = 4;
+      else
+        ft->writemode = 0;
+      ft->hexcase = gtk_toggle_button_get_active
+                                (GTK_TOGGLE_BUTTON (propdlg.radio_upper));
+      if (propdlg.combo)
+#if GTK_CHECK_VERSION(2,4,0)
+        ft->crlf = gtk_combo_box_get_active (GTK_COMBO_BOX (propdlg.combo));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+        {
+          const gchar *text;
+          GList *glist;
+
+          text = gtk_entry_get_text
+                                (GTK_ENTRY (GTK_COMBO (propdlg.combo)->entry));
+          glist = gtk_container_children
+                            (GTK_CONTAINER (GTK_COMBO (propdlg.combo)->list));
+          for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
+            if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), text) == 0)
+              break;
+          g_list_free (glist);
+          if (ft->crlf < 0)
+            ft->crlf = 0;
+        }
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+      g_free (ft->charset);
+      if (propdlg.charset)
+        ft->charset = orz_charset_get_charset (ORZ_CHARSET (propdlg.charset));
+      if (button_auto)
+        {
+          ft->charset = propdlg.charset_list;
+          propdlg.charset_list = NULL;
+        }
+      g_memmove (ft->color, propdlg.gdk_color, sizeof (GdkColor) * 12);
+      g_free (ft->font_name);
+#if GTK_CHECK_VERSION(2,4,0)
+      ft->font_name = g_strdup (gtk_font_button_get_font_name
+                                    (GTK_FONT_BUTTON (propdlg.button_font)));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+      ft->font_name = propdlg.font_name;
+      propdlg.font_name = NULL;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+    }
+  gtk_widget_destroy (propdlg.dialog);
 
   g_free (propdlg.charset_list);
 #if ! GTK_CHECK_VERSION(2,4,0)
   g_free (propdlg.font_name);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 
-  return propdlg.clicked_ok;
+  return result;
 }
