@@ -55,9 +55,12 @@ property_change (TmaidWindow *tmaid,
 *                                                                             *
 ******************************************************************************/
 /*  ja:プロパティダイアログ表示
-     ft,ファイルタイプ
-    RET,TRUE:OK,FALSE:Cancel                                                */
-gboolean property_dialog(FileType *ft);
+    parent,親ウインドウ
+        ft,ファイルタイプ
+       RET,TRUE:OK,FALSE:Cancel                                             */
+gboolean
+property_dialog (GtkWindow *parent,
+                 FileType  *ft);
 
 
 #ifdef __cplusplus
