@@ -26,59 +26,29 @@
 * ja:リロードダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-static gboolean reload_clicked_ok;
-static GtkWidget *dialog, *button0, *check0, *check1, *combo, *charset;
-
-
 /* ja:OKボタンの表示/非表示を判定 */
 static void
 reload_dialog_ok_sensitive (GtkWidget *widget,
-                            gpointer   user_data)
+                            GtkWidget *dialog)
 {
-  gtk_widget_set_sensitive (button0,
-                            orz_charset_is_valid (ORZ_CHARSET (charset)));
-}
+  GtkWidget *charset;
 
-
-/* ja:OKボタンが押された */
-static void
-reload_dialog_clicked (GtkWidget *widget,
-                       FileType  *ft)
-{
-#if ! GTK_CHECK_VERSION(2,4,0)
-  const gchar *str;
-  GList *glist;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-
-  g_free (ft->charset);
-  ft->html = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check0));
-  ft->esc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check1));
-#if GTK_CHECK_VERSION(2,4,0)
-  ft->crlf = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  str = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
-  glist = gtk_container_children (GTK_CONTAINER (GTK_COMBO (combo)->list));
-  for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
-    if (!g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                        (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), str))
-      break;
-  g_list_free (glist);
-  if (ft->crlf < 0)
-    ft->crlf = 0;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  ft->charset = orz_charset_get_charset (ORZ_CHARSET (charset));
-  gtk_widget_destroy (dialog);
-  reload_clicked_ok = TRUE;
+  charset = g_object_get_data (G_OBJECT (dialog), "user_data");
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
+                                orz_charset_is_valid (ORZ_CHARSET (charset)));
 }
 
 
 /* ja:コンボボックスでリターンが押された */
 static void
 reload_dialog_activate (GtkWidget *widget,
-                        FileType  *ft)
+                        GtkWidget *dialog)
 {
-  if (GTK_WIDGET_IS_SENSITIVE (button0))
-    reload_dialog_clicked (widget, ft);
+  GtkWidget *charset;
+
+  charset = g_object_get_data (G_OBJECT (dialog), "user_data");
+  if (orz_charset_is_valid (ORZ_CHARSET (charset)))
+    gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 }
 
 
@@ -89,7 +59,7 @@ reload_dialog_key_press (GtkWidget   *widget,
                          gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
@@ -102,36 +72,32 @@ gboolean
 reload_dialog (FileType    *ft,
                const gchar *text)
 {
+  gboolean result;
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  GtkWidget *button1, *hbox, *vbox;
+  GtkWidget *dialog, *check0, *check1, *combo, *charset, *vbox;
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Reload"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("Reload"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            NULL);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                 G_CALLBACK (reload_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
   /* ja:ボタン */
   if (text)
-    {
-      button0 = gtk_button_new_with_mnemonic (_("_Yes"));
-      button1 = gtk_button_new_with_mnemonic (_("_No"));
-    }
+    gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                            GTK_STOCK_YES, GTK_RESPONSE_ACCEPT,
+                            GTK_STOCK_NO, GTK_RESPONSE_REJECT,
+                            NULL);
   else
-    {
-      button0 = gtk_button_new_with_label (_("OK"));
-      button1 = gtk_button_new_with_label (_("Cancel"));
-    }
-  g_signal_connect (G_OBJECT (button0), "clicked",
-                                    G_CALLBACK (reload_dialog_clicked), ft);
-  g_signal_connect_swapped (G_OBJECT (button1), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
+    gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                            GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                            NULL);
   /* ja:チェックボタン */
   check0 = gtk_check_button_new_with_mnemonic
                                     (_("_HTML Numeric character reference"));
@@ -139,9 +105,9 @@ reload_dialog (FileType    *ft,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check0), ft->html);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check1), ft->esc);
   g_signal_connect (G_OBJECT (check0), "toggled",
-                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+                            G_CALLBACK (reload_dialog_ok_sensitive), dialog);
   g_signal_connect (G_OBJECT (check1), "toggled",
-                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+                            G_CALLBACK (reload_dialog_ok_sensitive), dialog);
   /* ja:コンボボックス */
 #if GTK_CHECK_VERSION(2,4,0)
   combo = gtk_combo_box_new_text ();
@@ -150,7 +116,7 @@ reload_dialog (FileType    *ft,
   gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "LF");
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), ft->crlf);
   g_signal_connect (G_OBJECT (combo), "changed",
-                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+                            G_CALLBACK (reload_dialog_ok_sensitive), dialog);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   glist = g_list_append (NULL, "CR+LF");
   glist = g_list_append (glist, "CR");
@@ -161,9 +127,9 @@ reload_dialog (FileType    *ft,
                                             g_list_nth_data (glist, ft->crlf));
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "activate",
-                                    G_CALLBACK (reload_dialog_activate), ft);
+                                G_CALLBACK (reload_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
-                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+                            G_CALLBACK (reload_dialog_ok_sensitive), dialog);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:文字符号化方式 */
   charset = orz_charset_new ();
@@ -171,13 +137,11 @@ reload_dialog (FileType    *ft,
     orz_charset_add_candidate (ORZ_CHARSET (charset), ftype[i].charset);
   orz_charset_set_charset (ORZ_CHARSET (charset), ft->charset);
   g_signal_connect (G_OBJECT (charset), "activate",
-                                    G_CALLBACK (reload_dialog_activate), ft);
+                                G_CALLBACK (reload_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (charset), "edited",
-                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+                            G_CALLBACK (reload_dialog_ok_sensitive), dialog);
+  g_object_set_data (G_OBJECT (dialog), "user_data", charset);
   /* ja:フレームとボックス */
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   if (text)
@@ -186,18 +150,38 @@ reload_dialog (FileType    *ft,
   gtk_box_pack_start (GTK_BOX (vbox), charset, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), check0, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), check1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), vbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_widget_grab_focus (text ? button1 : button0);
+  gtk_widget_show_all (vbox);
 
-  reload_clicked_ok = FALSE;
+  result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT;
+  if (result)
+    {
+#if ! GTK_CHECK_VERSION(2,4,0)
+      const gchar *str;
+      GList *glist;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+      g_free (ft->charset);
+      ft->html = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check0));
+      ft->esc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check1));
+#if GTK_CHECK_VERSION(2,4,0)
+      ft->crlf = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+      str = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
+      glist = gtk_container_children (GTK_CONTAINER (GTK_COMBO (combo)->list));
+      for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
+        if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                    (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), str) == 0)
+          break;
+      g_list_free (glist);
+      if (ft->crlf < 0)
+        ft->crlf = 0;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+      ft->charset = orz_charset_get_charset (ORZ_CHARSET (charset));
+    }
+  gtk_widget_destroy (dialog);
 
-  return reload_clicked_ok;
+  return result;
 }
