@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,17 +26,6 @@
 * ja:置換情報ダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-/* ja:ボタンが押された */
-static void
-repinfo_dialog_clicked (GtkWidget *widget,
-                        GtkWidget *dialog)
-{
-  *(gint *)g_object_get_data (G_OBJECT (dialog), "user_data")
-                    = (gint)g_object_get_data (G_OBJECT (widget), "user_data");
-  gtk_widget_destroy(dialog);
-}
-
-
 /* ja:ESCが押された */
 static gboolean
 repinfo_dialog_key_press (GtkWidget   *widget,
@@ -44,7 +33,7 @@ repinfo_dialog_key_press (GtkWidget   *widget,
                           gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
@@ -56,38 +45,21 @@ gint
 repinfo_dialog (ReplaceInfo *ri)
 {
   gchar *text;
-  gint result = REPLACE_CANCEL;
-  GtkWidget *dialog, *button0, *button1, *button2, *button3;
-  GtkWidget *frame0, *frame1, *hbox, *tbox, *vbox;
+  gint result;
+  GtkWidget *dialog, *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Replace Information"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("Replace Information"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
+                            _("_Next"), REPLACE_NEXT,
+                            _("_All Replace"), REPLACE_ALL,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                 G_CALLBACK (repinfo_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_object_set_data (G_OBJECT (dialog), "user_data", &result);
-  /* ja:ボタン */
-  button0 = gtk_button_new_with_mnemonic (_("_Replace"));
-  button1 = gtk_button_new_with_mnemonic (_("_Next"));
-  button2 = gtk_button_new_with_mnemonic (_("_All Replace"));
-  button3=gtk_button_new_with_label(_("Cancel"));
-  g_signal_connect (G_OBJECT (button0), "clicked",
-                                G_CALLBACK (repinfo_dialog_clicked), dialog);
-  g_signal_connect (G_OBJECT (button1), "clicked",
-                                G_CALLBACK (repinfo_dialog_clicked), dialog);
-  g_signal_connect (G_OBJECT (button2), "clicked",
-                                G_CALLBACK (repinfo_dialog_clicked), dialog);
-  g_signal_connect_swapped (G_OBJECT (button3), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  g_object_set_data (G_OBJECT (button0), "user_data", (gpointer)REPLACE_OK);
-  g_object_set_data (G_OBJECT (button1), "user_data", (gpointer)REPLACE_NEXT);
-  g_object_set_data (G_OBJECT (button2), "user_data", (gpointer)REPLACE_ALL);
-  GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button3, GTK_CAN_DEFAULT);
   /* ja:フレームとボックス */
   tbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (tbox), SPACING);
@@ -96,7 +68,7 @@ repinfo_dialog (ReplaceInfo *ri)
                         gtk_label_new (_("Find String")), FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox),
                         gtk_label_new (ri->src ? ri->src : ""), TRUE, TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+  gtk_box_pack_start (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_box_pack_start (GTK_BOX (hbox),
                         gtk_label_new (_("Replace String")), FALSE, FALSE, 0);
@@ -104,7 +76,7 @@ repinfo_dialog (ReplaceInfo *ri)
                         gtk_label_new (ri->dst ? ri->dst : ""), TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_start(GTK_BOX(hbox),
+  gtk_box_pack_start (GTK_BOX (hbox),
                          gtk_label_new (_("Replace Range")), FALSE, FALSE, 0);
   text = g_strdup_printf (_("(%d,%d)-(%d,%d)"),
             ri->start.x + 1, ri->start.y + 1, ri->end.x + 1, ri->end.y + 1);
@@ -123,28 +95,22 @@ repinfo_dialog (ReplaceInfo *ri)
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox),
-            gtk_label_new (ri->arrow ? _("Up") : _("Down")), FALSE, FALSE, 0);
+            gtk_label_new (ri->arrow ? _("Down") : _("Up")), FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (frame1), vbox);
 
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_box_pack_start (GTK_BOX (hbox), frame0, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), frame1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (tbox), hbox, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox), button3, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button2, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), tbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), tbox);
 
   /* ja:表示 */
-  gtk_widget_grab_focus (button1);
+  gtk_widget_show_all (tbox);
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+  result = gtk_dialog_run (GTK_DIALOG (dialog));
+  if (result != REPLACE_OK && result != REPLACE_NEXT && result != REPLACE_ALL)
+    result = REPLACE_CANCEL;
+  gtk_widget_destroy (dialog);
 
   return result;
 }
