@@ -32,82 +32,35 @@ gint replace_num = 0;                       /* ja:登録されている置換文
 * ja:置換ダイアログ関数群                                                     *
 *                                                                             *
 ******************************************************************************/
-static gint replace_clicked_button;
-static GtkWidget *dialog;
-static GtkWidget *button0, *button1, *check, *combo0, *combo1, *radio1;
-
-
-/* ja:置換ボタンが押された */
-static void
-replace_dialog_clicked_ok (GtkWidget     *widget,
-                           ReplaceString *rp)
-{
-#if GTK_CHECK_VERSION(2,4,0)
-  rp->src = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo0)->child)));
-  rp->dst = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo1)->child)));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  rp->src = g_strdup (gtk_entry_get_text
-                                    (GTK_ENTRY (GTK_COMBO (combo0)->entry)));
-  rp->dst = g_strdup (gtk_entry_get_text
-                                    (GTK_ENTRY (GTK_COMBO (combo1)->entry)));
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  rp->ignorecase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
-  rp->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
-  gtk_widget_destroy (dialog);
-  replace_clicked_button = REPLACE_OK;
-}
-
-
-/* ja:すべて置換ボタンが押された */
-static void
-replace_dialog_clicked_all (GtkWidget     *widget,
-                            ReplaceString *rp)
-{
-#if GTK_CHECK_VERSION(2,4,0)
-  rp->src = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo0)->child)));
-  rp->dst = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo1)->child)));
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  rp->src = g_strdup (gtk_entry_get_text
-                                    (GTK_ENTRY (GTK_COMBO (combo0)->entry)));
-  rp->dst = g_strdup (gtk_entry_get_text
-                                    (GTK_ENTRY (GTK_COMBO (combo1)->entry)));
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-  rp->ignorecase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
-  rp->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
-  gtk_widget_destroy (dialog);
-  replace_clicked_button = REPLACE_ALL;
-}
-
-
 /* ja:エントリーでリターンが押された */
 static void
-replace_dialog_activate (GtkWidget     *widget,
-                         ReplaceString *rp)
+replace_dialog_activate (GtkWidget *widget,
+                         GtkWidget *dialog)
 {
+  GtkWidget *combo;
+
+  combo = g_object_get_data (G_OBJECT (dialog), "user_data");
 #if GTK_CHECK_VERSION(2,4,0)
-  if (g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo0)->child))) > 0)
+  if (g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child))) > 0)
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  if (g_strlen (gtk_entry_get_text
-                                (GTK_ENTRY (GTK_COMBO (combo0)->entry))) > 0)
+  if (g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry))) > 0)
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-    replace_dialog_clicked_ok(widget,rp);
+    gtk_dialog_response (GTK_DIALOG (dialog), REPLACE_OK);
 }
 
 
 /* ja:エントリーが変更された */
 static void
 replace_dialog_changed (GtkWidget *widget,
-                        gpointer   user_data)
+                        GtkWidget *dialog)
 {
   gboolean sensitive;
 
   sensitive = g_strlen (gtk_entry_get_text (GTK_ENTRY (widget))) > 0;
-  gtk_widget_set_sensitive (button0, sensitive);
-  gtk_widget_set_sensitive (button1, sensitive);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REPLACE_OK,
+                                                                    sensitive);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REPLACE_ALL,
+                                                                    sensitive);
 }
 
 
@@ -118,7 +71,7 @@ replace_dialog_key_press (GtkWidget   *widget,
                           gpointer     user_data)
 {
   if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
   return FALSE;
 }
 
@@ -130,33 +83,24 @@ gint
 replace_dialog (ReplaceString *rp)
 {
   gboolean sensitive;
-  gint i;
+  gint i, result;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  GtkWidget *radio0, *button2;
+  GtkWidget *dialog, *check, *combo0, *combo1, *radio0, *radio1;
   GtkWidget *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Replace"));
+  dialog = gtk_dialog_new_with_buttons
+                            (_("Replace"),
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
+                            _("_All Replace"), REPLACE_ALL,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            NULL);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                 G_CALLBACK (replace_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  /* ja:ボタン */
-  button0 = gtk_button_new_with_mnemonic (_("_Replace"));
-  button1 = gtk_button_new_with_mnemonic (_("_All Replace"));
-  button2 = gtk_button_new_with_label (_("Cancel"));
-  g_signal_connect (G_OBJECT (button0), "clicked",
-                                G_CALLBACK (replace_dialog_clicked_ok), rp);
-  g_signal_connect (G_OBJECT (button1), "clicked",
-                                G_CALLBACK (replace_dialog_clicked_all), rp);
-  g_signal_connect_swapped (G_OBJECT (button2), "clicked",
-                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
-  GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
   /* ja:チェックボタン */
   check = gtk_check_button_new_with_mnemonic (_("Enable _Case"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), rp->ignorecase);
@@ -171,8 +115,8 @@ replace_dialog (ReplaceString *rp)
   if (find_num > 0)
     {
       gtk_combo_box_set_active (GTK_COMBO_BOX (combo0), 0);
-      gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo0)->child),
-                                                                        0, -1);
+      gtk_editable_select_region
+                            (GTK_EDITABLE (GTK_BIN (combo0)->child), 0, -1);
     }
   if (replace_num > 0)
     {
@@ -181,11 +125,11 @@ replace_dialog (ReplaceString *rp)
                                                                         0, -1);
     }
   g_signal_connect (G_OBJECT (GTK_BIN (combo0)->child), "activate",
-                                    G_CALLBACK (replace_dialog_activate), rp);
+                                G_CALLBACK (replace_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_BIN (combo1)->child), "activate",
-                                    G_CALLBACK (replace_dialog_activate), rp);
+                                G_CALLBACK (replace_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_BIN (combo0)->child), "changed",
-                                    G_CALLBACK (replace_dialog_changed), NULL);
+                                G_CALLBACK (replace_dialog_changed), dialog);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; i < find_num; i++)
     glist = g_list_append (glist, find_text[i]);
@@ -196,14 +140,14 @@ replace_dialog (ReplaceString *rp)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo0), glist);
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo0)->entry), find_text[0]);
-      gtk_editable_select_region (GTK_EDITABLE (GTK_COMBO (combo0)->entry),
-                                                                        0,-1);
+      gtk_editable_select_region
+                            (GTK_EDITABLE (GTK_COMBO (combo0)->entry), 0,-1);
       g_list_free (glist);
     }
   g_signal_connect (G_OBJECT (GTK_COMBO (combo0)->entry), "activate",
-                                    G_CALLBACK (replace_dialog_activate), rp);
+                                G_CALLBACK (replace_dialog_activate), dialog);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo0)->entry), "changed",
-                                    G_CALLBACK (replace_dialog_changed), NULL);
+                                G_CALLBACK (replace_dialog_changed), dialog);
   glist = NULL;
   for (i = 0; i < replace_num; i++)
     glist = g_list_append (glist, replace_text[i]);
@@ -218,7 +162,7 @@ replace_dialog (ReplaceString *rp)
       g_list_free (glist);
     }
   g_signal_connect (G_OBJECT (GTK_COMBO (combo1)->entry), "activate",
-                                    G_CALLBACK (replace_dialog_activate), rp);
+                                G_CALLBACK (replace_dialog_activate), dialog);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_mnemonic (NULL, _("_Up"));
@@ -257,12 +201,7 @@ replace_dialog (ReplaceString *rp)
   gtk_box_pack_start (GTK_BOX (hbox), frame0, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), frame1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (tbox), hbox, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_end (GTK_BOX (hbox), button2, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (tbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), tbox);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), tbox);
 
   /* ja:表示 */
 #if GTK_CHECK_VERSION(2,4,0)
@@ -272,19 +211,40 @@ replace_dialog (ReplaceString *rp)
   sensitive = g_strlen (gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo0)->entry))) > 0;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  gtk_widget_set_sensitive (button0, sensitive);
-  gtk_widget_set_sensitive (button1, sensitive);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REPLACE_OK,
+                                                                    sensitive);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REPLACE_ALL,
+                                                                    sensitive);
 #if GTK_CHECK_VERSION(2,4,0)
   gtk_widget_grab_focus (GTK_BIN (combo0)->child);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_widget_grab_focus (GTK_COMBO (combo0)->entry);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-  replace_clicked_button = REPLACE_CANCEL;
+  gtk_widget_show_all (tbox);
 
-  gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
+  result = gtk_dialog_run (GTK_DIALOG (dialog));
+  if (result == REPLACE_OK || result == REPLACE_ALL)
+    {
+#if GTK_CHECK_VERSION(2,4,0)
+      rp->src = g_strdup (gtk_entry_get_text
+                                        (GTK_ENTRY (GTK_BIN (combo0)->child)));
+      rp->dst = g_strdup (gtk_entry_get_text
+                                        (GTK_ENTRY (GTK_BIN (combo1)->child)));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+      rp->src = g_strdup (gtk_entry_get_text
+                                    (GTK_ENTRY (GTK_COMBO (combo0)->entry)));
+      rp->dst = g_strdup (gtk_entry_get_text
+                                    (GTK_ENTRY (GTK_COMBO (combo1)->entry)));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+      rp->ignorecase = gtk_toggle_button_get_active
+                                                (GTK_TOGGLE_BUTTON (check));
+      rp->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
+    }
+  else
+    {
+      result = REPLACE_CANCEL;
+    }
+  gtk_widget_destroy (dialog);
 
-  return replace_clicked_button;
+  return result;
 }
