@@ -26,7 +26,7 @@
 *                                                                             *
 ******************************************************************************/
 /* XPM */
-static const gchar *tb_new_xpm[] = {
+const static gchar *tb_new_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -51,7 +51,7 @@ static const gchar *tb_new_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_open_xpm[] = {
+const static gchar *tb_open_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -77,7 +77,7 @@ static const gchar *tb_open_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_save_xpm[] = {
+const static gchar *tb_save_xpm[] = {
 "16 16 5 1",
 "  c None",
 ". c #000000",
@@ -102,7 +102,7 @@ static const gchar *tb_save_xpm[] = {
 "                "};
 
 
-static const gchar *tb_prop_xpm[] = {
+const static gchar *tb_prop_xpm[] = {
 "16 16 4 1",
 "  c None",
 ". c #000000",
@@ -126,7 +126,7 @@ static const gchar *tb_prop_xpm[] = {
 "                "};
 
 
-static const gchar *tb_print_xpm[] = {
+const static gchar *tb_print_xpm[] = {
 "16 16 7 1",
 "   c None",
 ".  c #000000",
@@ -154,7 +154,7 @@ static const gchar *tb_print_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_cut_xpm[] = {
+const static gchar *tb_cut_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -180,7 +180,7 @@ static const gchar *tb_cut_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_copy_xpm[] = {
+const static gchar *tb_copy_xpm[] = {
 "16 16 4 1",
 "   c None",
 ".  c #000000",
@@ -205,7 +205,7 @@ static const gchar *tb_copy_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_paste_xpm[] = {
+const static gchar *tb_paste_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -231,7 +231,7 @@ static const gchar *tb_paste_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_delete_xpm[] = {
+const static gchar *tb_delete_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
@@ -254,7 +254,7 @@ static const gchar *tb_delete_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_undo_xpm[] = {
+const static gchar *tb_undo_xpm[] = {
 "16 16 2 1",
 "   c None",
 "-  c #FF0000",
@@ -277,7 +277,7 @@ static const gchar *tb_undo_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_redo_xpm[] = {
+const static gchar *tb_redo_xpm[] = {
 "16 16 2 1",
 "   c None",
 ",  c #0000FF",
@@ -300,7 +300,7 @@ static const gchar *tb_redo_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_find_xpm[] = {
+const static gchar *tb_find_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
@@ -326,7 +326,7 @@ static const gchar *tb_find_xpm[] = {
 
 
 /* XPM */
-static const gchar *tb_replace_xpm[] = {
+const static gchar *tb_replace_xpm[] = {
 "16 16 5 1",
 "   c None",
 ".  c #000000",
